@@ -1,3 +1,7 @@
+# frozen_string_literal: true
+
+require 'stringio'
+
 class Pry
   # Manage the processing of command line options
   class CLI
@@ -33,9 +37,7 @@ class Pry
 
       # Bring in options defined in plugins
       def add_plugin_options
-        Pry.plugins.values.each do |plugin|
-          plugin.load_cli_options
-        end
+        Pry.plugins.values.each(&:load_cli_options)
 
         self
       end
@@ -56,14 +58,22 @@ class Pry
 
       def parse_options(args = ARGV)
         unless options
-          raise NoOptionsError, "No command line options defined! Use Pry::CLI.add_options to add command line options."
+          raise NoOptionsError,
+                "No command line options defined! Use Pry::CLI.add_options to " \
+                "add command line options."
         end
 
-        self.input_args = args
+        @pass_argv = args.index { |cli_arg| %w[- --].include?(cli_arg) }
+        if @pass_argv
+          slop_args = args[0...@pass_argv]
+          self.input_args = args.replace(args[@pass_argv + 1..-1])
+        else
+          self.input_args = slop_args = args
+        end
 
         begin
           opts = Pry::Slop.parse!(
-            args,
+            slop_args,
             help: true,
             multiple_switches: false,
             strict: true,
@@ -72,22 +82,20 @@ class Pry
         rescue Pry::Slop::InvalidOptionError
           # Display help message on unknown switches and exit.
           puts Pry::Slop.new(&options)
-          exit
+          Kernel.exit
         end
 
         Pry.initial_session_setup
         Pry.final_session_setup
 
         # Option processors are optional.
-        if option_processors
-          option_processors.each { |processor| processor.call(opts) }
-        end
+        option_processors.each { |processor| processor.call(opts) } if option_processors
 
         opts
       end
 
       def start(opts)
-        exit if opts.help?
+        Kernel.exit if opts.help?
 
         # invoked via cli
         Pry.cli = true
@@ -95,16 +103,16 @@ class Pry
         # create the actual context
         if opts[:context]
           Pry.initial_session_setup
-          context = Pry.binding_for(eval(opts[:context]))
+          context = Pry.binding_for(eval(opts[:context])) # rubocop:disable Security/Eval
           Pry.final_session_setup
         else
           context = Pry.toplevel_binding
         end
 
-        if Pry::CLI.input_args.any? && Pry::CLI.input_args != ["pry"]
+        if !@pass_argv && Pry::CLI.input_args.any? && Pry::CLI.input_args != ["pry"]
           full_name = File.expand_path(Pry::CLI.input_args.first)
           Pry.load_file_through_repl(full_name)
-          exit
+          Kernel.exit
         end
 
         # Start the session (running any code passed with -e, if there is any)
@@ -123,20 +131,21 @@ Pry::Slop.new do
   end
 end.parse(ARGV.dup)
 
-if Pry.config.should_load_plugins
-  Pry::CLI.add_plugin_options
-end
+Pry::CLI.add_plugin_options if Pry.config.should_load_plugins
 
 # The default Pry command line options (before plugin options are included)
 Pry::CLI.add_options do
   banner(
     "Usage: pry [OPTIONS]\n" \
     "Start a Pry session.\n" \
-    "See http://pryrepl.org/ for more information.\n"
+    "See http://pryrepl.org/ for more information.\n" \
+    "Copyright (c) 2016 John Mair (banisterfiend)" \
   )
 
-  on :e, :exec=, "A line of code to execute in context before the session starts" do |input|
-    Pry.config.exec_string += "\n" if Pry.config.exec_string.length > 0
+  on(
+    :e, :exec=, "A line of code to execute in context before the session starts"
+  ) do |input|
+    Pry.config.exec_string += "\n" unless Pry.config.exec_string.empty?
     Pry.config.exec_string += input
   end
 
@@ -174,32 +183,32 @@ Pry::CLI.add_options do
     puts "Installed Plugins:"
     puts "--"
     Pry.locate_plugins.each do |plugin|
-      puts "#{plugin.name}".ljust(18) << plugin.spec.summary
+      puts plugin.name.to_s.ljust(18) << plugin.spec.summary
     end
-    exit
+    Kernel.exit
   end
 
   on "simple-prompt", "Enable simple prompt mode" do
-    Pry.config.prompt = Pry::Prompt[:simple][:value]
+    Pry.config.prompt = Pry::Prompt[:simple]
   end
 
   on "noprompt", "No prompt mode" do
-    Pry.config.prompt = Pry::Prompt[:none][:value]
+    Pry.config.prompt = Pry::Prompt[:none]
   end
 
   on :r, :require=, "`require` a Ruby script at startup" do |file|
     Pry.config.requires << file
   end
 
-  on :I=, "Add a path to the $LOAD_PATH", as: Array, delimiter: ":" do |load_path|
+  on(:I=, "Add a path to the $LOAD_PATH", as: Array, delimiter: ":") do |load_path|
     load_path.map! do |path|
-      /\A\.\// =~ path ? path : File.expand_path(path)
+      %r{\A\./} =~ path ? path : File.expand_path(path)
     end
 
     $LOAD_PATH.unshift(*load_path)
   end
 
-  on "gem", "Shorthand for -I./lib -rgemname" do |load_path|
+  on "gem", "Shorthand for -I./lib -rgemname" do |_load_path|
     $LOAD_PATH.unshift("./lib")
     Dir["./lib/*.rb"].each do |file|
       Pry.config.requires << file
@@ -208,11 +217,11 @@ Pry::CLI.add_options do
 
   on :v, :version, "Display the Pry version" do
     puts "Pry version #{Pry::VERSION} on Ruby #{RUBY_VERSION}"
-    exit
+    Kernel.exit
   end
 
-  on(:c, :context=,
-     "Start the session in the specified context. Equivalent to `context.pry` in a session.",
+  on :c, :context=,
+     "Start the session in the specified context. Equivalent to " \
+     "`context.pry` in a session.",
      default: "Pry.toplevel_binding"
-     )
 end
