@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 class Pry
   class Code
-    # Represents a line of code (which may, in fact, contain multiple lines if the
-    # entirety was eval'd as a single unit following the `edit` command).
+    # Represents a line of code (which may, in fact, contain multiple lines if
+    # the entirety was eval'd as a single unit following the `edit` command).
     #
     # A line of code is a tuple, which consists of a line and a line number. A
     # `LOC` object's state (namely, the line parameter) can be changed via
@@ -52,7 +54,7 @@ class Pry
       # @param [Symbol] code_type
       # @return [void]
       def colorize(code_type)
-        tuple[0] = CodeRay.scan(line, code_type).term
+        tuple[0] = SyntaxHighlighter.highlight(line, code_type)
       end
 
       # Prepends the line number `lineno` to the `line`.
@@ -61,9 +63,14 @@ class Pry
       # @return [void]
       def add_line_number(max_width = 0, color = false)
         padded = lineno.to_s.rjust(max_width)
-        colorized_lineno = color ? Pry::Helpers::BaseHelpers.colorize_code(padded) : padded
+        colorized_lineno =
+          if color
+            Pry::Helpers::BaseHelpers.colorize_code(padded)
+          else
+            padded
+          end
         properly_padded_line = handle_multiline_entries_from_edit_command(line, max_width)
-        tuple[0] = "#{ colorized_lineno }: #{ properly_padded_line }"
+        tuple[0] = "#{colorized_lineno}: #{properly_padded_line}"
       end
 
       # Prepends a marker "=>" or an empty marker to the +line+.
@@ -74,9 +81,9 @@ class Pry
       def add_marker(marker_lineno)
         tuple[0] =
           if lineno == marker_lineno
-            " => #{ line }"
+            " => #{line}"
           else
-            "    #{ line }"
+            "    #{line}"
           end
       end
 
@@ -85,7 +92,7 @@ class Pry
       # @param [Integer] distance
       # @return [void]
       def indent(distance)
-        tuple[0] = "#{ ' ' * distance }#{ line }"
+        tuple[0] = "#{' ' * distance}#{line}"
       end
 
       def handle_multiline_entries_from_edit_command(line, max_width)
