@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class Pry
   class NoCommandError < StandardError
     def initialize(match, owner)
@@ -29,16 +31,12 @@ class Pry
     # @option options [Boolean] :keep_retval Whether or not to use return value
     #   of the block for return of `command` or just to return `nil`
     #   (the default).
-    # @option options [Array<String>] :requires_gem Whether the command has
-    #   any gem dependencies, if it does and dependencies not met then
-    #   command is disabled and a stub proc giving instructions to
-    #   install command is provided.
     # @option options [Boolean] :interpolate Whether string #{} based
     #   interpolation is applied to the command arguments before
     #   executing the command. Defaults to true.
     # @option options [String] :listing The listing name of the
     #   command. That is the name by which the command is looked up by
-    #   help and by show-command. Necessary for commands with regex matches.
+    #   help and by show-source. Necessary for commands with regex matches.
     # @option options [Boolean] :use_prefix Whether the command uses
     #   `Pry.config.command_prefix` prefix (if one is defined). Defaults
     #   to true.
@@ -57,31 +55,38 @@ class Pry
     #   end
     #
     #   # From pry:
-    #   # pry(main)> _pry_.commands = MyCommands
+    #   # pry(main)> pry_instance.commands = MyCommands
     #   # pry(main)> greet john
     #   # Good afternoon John!
     #   # pry(main)> help greet
     #   # Greet somebody
     # @example Regexp command
     #   MyCommands = Pry::CommandSet.new do
-    #     command /number-(\d+)/, "number-N regex command", :listing => "number" do |num, name|
+    #     command(
+    #       /number-(\d+)/, "number-N regex command", :listing => "number"
+    #     ) do |num, name|
     #       puts "hello #{name}, nice number: #{num}"
     #     end
     #   end
     #
     #   # From pry:
-    #   # pry(main)> _pry_.commands = MyCommands
+    #   # pry(main)> pry_instance.commands = MyCommands
     #   # pry(main)> number-10 john
     #   # hello john, nice number: 10
     #   # pry(main)> help number
     #   # number-N regex command
-    def block_command(match, description="No description.", options={}, &block)
-      description, options = ["No description.", description] if description.is_a?(Hash)
+    def block_command(match, description = "No description.", options = {}, &block)
+      if description.is_a?(Hash)
+        options = description
+        description = "No description."
+      end
       options = Pry::Command.default_options(match).merge!(options)
 
-      @commands[match] = Pry::BlockCommand.subclass(match, description, options, helper_module, &block)
+      @commands[match] = Pry::BlockCommand.subclass(
+        match, description, options, helper_module, &block
+      )
     end
-    alias_method :command, :block_command
+    alias command block_command
 
     # Defines a new Pry command class.
     #
@@ -99,7 +104,9 @@ class Pry
     #     end
     #
     #     def process
-    #       raise Pry::CommandError, "-u and -d makes no sense" if opts.present?(:u) && opts.present?(:d)
+    #       if opts.present?(:u) && opts.present?(:d)
+    #         raise Pry::CommandError, "-u and -d makes no sense"
+    #       end
     #       result = args.join(" ")
     #       result.downcase! if opts.present?(:downcase)
     #       result.upcase! if opts.present?(:upcase)
@@ -107,56 +114,27 @@ class Pry
     #     end
     #   end
     #
-    def create_command(match, description="No description.", options={}, &block)
-      description, options = ["No description.", description] if description.is_a?(Hash)
+    def create_command(match, description = "No description.", options = {}, &block)
+      if description.is_a?(Hash)
+        options = description
+        description = "No description."
+      end
       options = Pry::Command.default_options(match).merge!(options)
 
-      @commands[match] = Pry::ClassCommand.subclass(match, description, options, helper_module, &block)
+      @commands[match] = Pry::ClassCommand.subclass(
+        match, description, options, helper_module, &block
+      )
       @commands[match].class_eval(&block)
       @commands[match]
     end
 
-    # Execute a block of code before a command is invoked. The block also
-    # gets access to parameters that will be passed to the command and
-    # is evaluated in the same context.
-    # @param [String, Regexp] search The match or listing of the command.
-    # @yield The block to be run before the command.
-    # @example Display parameter before invoking command
-    #   Pry.config.commands.before_command("whereami") do |n|
-    #     output.puts "parameter passed was #{n}"
-    #   end
-    # @deprecated Use {Pry::Hooks#add_hook} instead.
-    def before_command(search, &block)
-      cmd = find_command_by_match_or_listing(search)
-      cmd.hooks.add_hook("before_#{cmd.command_name}", random_hook_name, block)
-    end
-
-    # Execute a block of code after a command is invoked. The block also
-    # gets access to parameters that will be passed to the command and
-    # is evaluated in the same context.
-    # @param [String, Regexp] search The match or listing of the command.
-    # @yield The block to be run after the command.
-    # @example Display text 'command complete' after invoking command
-    #   Pry.config.commands.after_command("whereami") do |n|
-    #     output.puts "command complete!"
-    #   end
-    # @deprecated Use {Pry::Hooks#add_hook} instead.
-    def after_command(search, &block)
-      cmd = find_command_by_match_or_listing(search)
-      cmd.hooks.add_hook("after_#{cmd.command_name}", random_hook_name, block)
-    end
-
-    def random_hook_name
-      (0...8).map { ('a'..'z').to_a[rand(26)] }.join
-    end
-    private :random_hook_name
-
     def each(&block)
       @commands.each(&block)
     end
 
     # Removes some commands from the set
-    # @param [Array<String>] searches the matches or listings of the commands to remove
+    # @param [Array<String>] searches the matches or listings of the commands
+    #   to remove
     def delete(*searches)
       searches.each do |search|
         cmd = find_command_by_match_or_listing(search)
@@ -195,7 +173,7 @@ class Pry
     def find_command_by_match_or_listing(match_or_listing)
       cmd = (@commands[match_or_listing] ||
         Pry::Helpers::BaseHelpers.find_command(match_or_listing, @commands))
-      cmd or raise ArgumentError, "Cannot find a command: '#{match_or_listing}'!"
+      cmd || raise(ArgumentError, "cannot find a command: '#{match_or_listing}'")
     end
 
     # Aliases a command
@@ -209,14 +187,14 @@ class Pry
     #   Pry.config.commands.alias_command "lM", "ls -M"
     # @example Pass explicit description (overriding default).
     #   Pry.config.commands.alias_command "lM", "ls -M", :desc => "cutiepie"
-    def alias_command(match, action,  options={})
-      cmd = find_command(action) or fail "Command: `#{action}` not found"
+    def alias_command(match, action, options = {})
+      (cmd = find_command(action)) || raise("command: '#{action}' not found")
       original_options = cmd.options.dup
 
-      options = original_options.merge!({
-                                          :desc => "Alias for `#{action}`",
-                                          :listing => match
-                                        }).merge!(options)
+      options = original_options.merge!(
+        desc: "Alias for `#{action}`",
+        listing: match.is_a?(String) ? match : match.inspect
+      ).merge!(options)
 
       # ensure default description is used if desc is nil
       desc = options.delete(:desc).to_s
@@ -225,6 +203,7 @@ class Pry
         run action, *args
       end
 
+      # TODO: untested. What's this about?
       c.class_eval do
         define_method(:complete) do |input|
           cmd.new(context).complete(input)
@@ -245,12 +224,12 @@ class Pry
     #   command description to be passed this way too.
     # @example Renaming the `ls` command and changing its description.
     #   Pry.config.commands.rename "dir", "ls", :description => "DOS friendly ls"
-    def rename_command(new_match, search, options={})
+    def rename_command(new_match, search, options = {})
       cmd = find_command_by_match_or_listing(search)
 
       options = {
-        :listing     => new_match,
-        :description => cmd.description
+        listing: new_match,
+        description: cmd.description
       }.merge!(options)
 
       @commands[new_match] = cmd.dup
@@ -260,17 +239,6 @@ class Pry
       @commands.delete(cmd.match)
     end
 
-    def disabled_command(name_of_disabled_command, message, matcher=name_of_disabled_command)
-      create_command name_of_disabled_command do
-        match matcher
-        description ""
-
-        define_method(:process) do
-          output.puts "DISABLED: #{message}"
-        end
-      end
-    end
-
     # Sets or gets the description for a command (replacing the old
     # description). Returns current description if no description
     # parameter provided.
@@ -282,53 +250,35 @@ class Pry
     #   end
     # @example Getting
     #   Pry.config.commands.desc "amend-line"
-    def desc(search, description=nil)
+    def desc(search, description = nil)
       cmd = find_command_by_match_or_listing(search)
-      return cmd.description if !description
+      return cmd.description unless description
 
       cmd.description = description
     end
 
-    # Defines helpers methods for this command sets.
-    # Those helpers are only defined in this command set.
-    #
-    # @yield A block defining helper methods
-    # @example
-    #   helpers do
-    #     def hello
-    #       puts "Hello!"
-    #     end
-    #
-    #     include OtherModule
-    #   end
-    def helpers(&block)
-      helper_module.class_eval(&block)
-    end
-
-
     # @return [Array]
     #   The list of commands provided by the command set.
     def list_commands
       @commands.keys
     end
-    alias_method :keys, :list_commands
+    alias keys list_commands
 
     def to_hash
       @commands.dup
     end
-    alias_method :to_h, :to_hash
+    alias to_h to_hash
 
     # Find a command that matches the given line
     # @param [String] pattern The line that might be a command invocation
     # @return [Pry::Command, nil]
     def [](pattern)
-      @commands.values.select do |command|
+      commands = @commands.values.select do |command|
         command.matches?(pattern)
-      end.sort_by do |command|
-        command.match_score(pattern)
-      end.last
+      end
+      commands.max_by { |command| command.match_score(pattern) }
     end
-    alias_method :find_command, :[]
+    alias find_command []
 
     #
     # Re-assign the command found at _pattern_ with _command_.
@@ -347,11 +297,14 @@ class Pry
     #
     def []=(pattern, command)
       if command.equal?(nil)
-        return @commands.delete(pattern)
+        @commands.delete(pattern)
+        return
       end
-      unless Class === command && command < Pry::Command
+
+      unless command.is_a?(Class) && command < Pry::Command
         raise TypeError, "command is not a subclass of Pry::Command"
       end
+
       bind_command_to_pattern = pattern != command.match
       if bind_command_to_pattern
         command_copy = command.dup
@@ -376,11 +329,12 @@ class Pry
     # @param [String] search The user's search.
     # @return [Pry::Command?]
     def find_command_for_help(search)
-      find_command(search) || (begin
-        find_command_by_match_or_listing(search)
-      rescue ArgumentError
-        nil
-      end)
+      find_command(search) ||
+        (begin
+           find_command_by_match_or_listing(search)
+         rescue ArgumentError
+           nil
+         end)
     end
 
     # Is the given line a command invocation?
@@ -394,9 +348,9 @@ class Pry
     # @param [String] val The line to execute
     # @param [Hash] context The context to execute the commands with
     # @return [CommandSet::Result]
-    def process_line(val, context={})
-      if command = find_command(val)
-        context = context.merge(:command_set => self)
+    def process_line(val, context = {})
+      if (command = find_command(val))
+        context = context.merge(command_set: self)
         retval = command.new(context).process_line(val)
         Result.new(true, retval)
       else
@@ -404,25 +358,38 @@ class Pry
       end
     end
 
-    # @private (used for testing)
-    def run_command(context, match, *args)
-      command = @commands[match] or raise NoCommandError.new(match, self)
-      command.new(context).call_safely(*args)
-    end
-
     # Generate completions for the user's search.
     # @param [String] search The line to search for
     # @param [Hash] context  The context to create the command with
     # @return [Array<String>]
-    def complete(search, context={})
-      if command = find_command(search)
+    def complete(search, context = {})
+      if (command = find_command(search))
         command.new(context).complete(search)
       else
-        @commands.keys.select do |key|
-          String === key && key.start_with?(search)
-        end.map{ |key| key + " " }
+        keys = @commands.keys.select do |key|
+          key.is_a?(String) && key.start_with?(search)
+        end
+        keys.map { |key| key + " " }
       end
     end
+
+    private
+
+    # Defines helpers methods for this command sets.
+    # Those helpers are only defined in this command set.
+    #
+    # @yield A block defining helper methods
+    # @example
+    #   helpers do
+    #     def hello
+    #       puts "Hello!"
+    #     end
+    #
+    #     include OtherModule
+    #   end
+    def helpers(&block)
+      helper_module.class_eval(&block)
+    end
   end
 
   # Wraps the return result of process_commands, indicates if the
@@ -431,7 +398,8 @@ class Pry
     attr_reader :retval
 
     def initialize(is_command, retval = nil)
-      @is_command, @retval = is_command, retval
+      @is_command = is_command
+      @retval = retval
     end
 
     # Is the result a command?
