@@ -1,10 +1,12 @@
+# frozen_string_literal: true
+
 class Pry
   # @return [Array] Code of the method used when implementing Pry's
   #   __binding__, along with line indication to be used with instance_eval (and
   #   friends).
   #
   # @see Object#__binding__
-  BINDING_METHOD_IMPL = [<<-METHOD, __FILE__, __LINE__ + 1]
+  BINDING_METHOD_IMPL = [<<-METHOD, __FILE__, __LINE__ + 1].freeze
     # Get a binding with 'self' set to self, and no locals.
     #
     # The default definee is determined by the context in which the
@@ -39,7 +41,7 @@ class Object
   #   my_method()
   # @see Pry.start
   def pry(object = nil, hash = {})
-    if object.nil? || Hash === object
+    if object.nil? || Hash === object # rubocop:disable Style/CaseEquality
       Pry.start(self, object || {})
     else
       Pry.start(object, hash)
@@ -81,10 +83,10 @@ class Object
       # This fixes the following two spec failures, at https://travis-ci.org/pry/pry/jobs/274470002
       # 1) ./spec/pry_spec.rb:360:in `block in (root)'
       # 2) ./spec/pry_spec.rb:366:in `block in (root)'
-      return class_eval { binding } if Pry::Helpers::Platform.jruby? and self.name == nil
+      return class_eval { binding } if Pry::Helpers::Platform.jruby? && name.nil?
 
       # class_eval sets both self and the default definee to this class.
-      return class_eval("binding")
+      return class_eval("binding", __FILE__, __LINE__)
     end
 
     unless self.class.method_defined?(:__pry__)
@@ -124,7 +126,7 @@ class BasicObject
     # BasicObjects don't have respond_to?, so we just define the method
     # every time. As they also don't have `.freeze`, this call won't
     # fail as it can for normal Objects.
-    (class << self; self; end).class_eval <<-EOF, __FILE__, __LINE__ + 1
+    (class << self; self; end).class_eval(<<-METHOD, __FILE__, __LINE__ + 1)
       # Get a binding with 'self' set to self, and no locals.
       #
       # The default definee is determined by the context in which the
@@ -136,7 +138,7 @@ class BasicObject
       def __pry__
         ::Kernel.binding
       end
-    EOF
-    self.__pry__
+    METHOD
+    __pry__
   end
 end
