@@ -1,9 +1,12 @@
+# frozen_string_literal: true
+
+require 'rbconfig'
+
 class Pry
   module Helpers
     # Contains methods for querying the platform that Pry is running on
     # @api public
     # @since v0.12.0
-    # rubocop:disable Style/DoubleNegation
     module Platform
       # @return [Boolean]
       def self.mac_osx?
@@ -25,7 +28,7 @@ class Pry
       def self.windows_ansi?
         return false unless windows?
 
-        !!(defined?(Win32::Console) || ENV['ANSICON'] || mri_2?)
+        !!(defined?(Win32::Console) || Pry::Env['ANSICON'] || mri_2?)
       end
 
       # @return [Boolean]
@@ -45,14 +48,13 @@ class Pry
 
       # @return [Boolean]
       def self.mri_19?
-        !!(mri? && RUBY_VERSION.start_with?('1.9'))
+        mri? && RUBY_VERSION.start_with?('1.9')
       end
 
       # @return [Boolean]
       def self.mri_2?
-        !!(mri? && RUBY_VERSION.start_with?('2'))
+        mri? && RUBY_VERSION.start_with?('2')
       end
     end
-    # rubocop:enable Style/DoubleNegation
   end
 end
