@@ -1,4 +1,4 @@
-require 'coderay'
+# frozen_string_literal: true
 
 class Pry
   ##
@@ -21,35 +21,35 @@ class Pry
     attr_reader :stack
 
     # The amount of spaces to insert for each indent level.
-    SPACES = '  '
+    SPACES = '  '.freeze
 
     # Hash containing all the tokens that should increase the indentation
     # level. The keys of this hash are open tokens, the values the matching
     # tokens that should prevent a line from being indented if they appear on
     # the same line.
     OPEN_TOKENS = {
-      'def'    => 'end',
-      'class'  => 'end',
+      'def' => 'end',
+      'class' => 'end',
       'module' => 'end',
-      'do'     => 'end',
-      'if'     => 'end',
+      'do' => 'end',
+      'if' => 'end',
       'unless' => 'end',
-      'while'  => 'end',
-      'until'  => 'end',
-      'for'    => 'end',
-      'case'   => 'end',
-      'begin'  => 'end',
-      '['      => ']',
-      '{'      => '}',
-      '('      => ')'
-    }
+      'while' => 'end',
+      'until' => 'end',
+      'for' => 'end',
+      'case' => 'end',
+      'begin' => 'end',
+      '[' => ']',
+      '{' => '}',
+      '(' => ')'
+    }.freeze
 
     # Which tokens can either be open tokens, or appear as modifiers on
     # a single-line.
-    SINGLELINE_TOKENS = %w(if while until unless rescue)
+    SINGLELINE_TOKENS = %w[if while until unless rescue].freeze
 
     # Which tokens can be followed by an optional "do" keyword.
-    OPTIONAL_DO_TOKENS = %w(for while until)
+    OPTIONAL_DO_TOKENS = %w[for while until].freeze
 
     # Collection of token types that should be ignored. Without this list
     # keywords such as "class" inside strings would cause the code to be
@@ -58,7 +58,7 @@ class Pry
     # :pre_constant and :preserved_constant are the CodeRay 0.9.8 and 1.0.0
     # classifications of "true", "false", and "nil".
     IGNORE_TOKENS = [:space, :content, :string, :method, :ident,
-                     :constant, :pre_constant, :predefined_constant]
+                     :constant, :pre_constant, :predefined_constant].freeze
 
     # Tokens that indicate the end of a statement (i.e. that, if they appear
     # directly before an "if" indicates that that if applies to the same line,
@@ -73,7 +73,7 @@ class Pry
 
     # Collection of tokens that should appear dedented even though they
     # don't affect the surrounding code.
-    MIDWAY_TOKENS = %w(when else elsif ensure rescue)
+    MIDWAY_TOKENS = %w[when else elsif ensure rescue].freeze
 
     # Clean the indentation of a fragment of ruby.
     #
@@ -101,7 +101,8 @@ class Pry
       indent.module_nesting
     end
 
-    def initialize
+    def initialize(pry_instance = Pry.new)
+      @pry_instance = pry_instance
       reset
     end
 
@@ -145,7 +146,9 @@ class Pry
       input.lines.each do |line|
         if in_string?
           tokens = tokenize("#{open_delimiters_line}\n#{line}")
-          tokens = tokens.drop_while { |token, type| !(String === token && token.include?("\n")) }
+          tokens = tokens.drop_while do |token, _type|
+            !(token.is_a?(String) && token.include?("\n"))
+          end
           previously_in_string = true
         else
           tokens = tokenize(line)
@@ -166,7 +169,7 @@ class Pry
 
       @indent_level = prefix
 
-      return output
+      output
     end
 
     # Get the indentation for the start of the next line.
@@ -193,7 +196,6 @@ class Pry
     # @return [Array[Integer]]
     #
     def indentation_delta(tokens)
-
       # We need to keep track of whether we've seen a "for" on this line because
       # if the line ends with "do" then that "do" should be discounted (i.e. we're
       # only opening one level not two) To do this robustly we want to keep track
@@ -204,20 +206,26 @@ class Pry
       # When deciding whether an "if" token is the start of a multiline statement,
       # or just the middle of a single-line if statement, we just look at the
       # preceding token, which is tracked here.
-      last_token, last_kind = [nil, nil]
+      last_token = nil
+      last_kind = nil
 
       # delta keeps track of the total difference from the start of each line after
       # the given token, 0 is just the level at which the current line started for
       # reference.
-      remove_before, add_after = [0, 0]
+      remove_before = 0
+      add_after = 0
 
       # If the list of tokens contains a matching closing token the line should
       # not be indented (and thus we should return true).
       tokens.each do |token, kind|
-        is_singleline_if = (SINGLELINE_TOKENS.include?(token)) && end_of_statement?(last_token, last_kind)
+        is_singleline_if =
+          SINGLELINE_TOKENS.include?(token) && end_of_statement?(last_token, last_kind)
         is_optional_do = (token == "do" && seen_for_at.include?(add_after - 1))
 
-        last_token, last_kind = token, kind unless kind == :space
+        unless kind == :space
+          last_token = token
+          last_kind = kind
+        end
         next if IGNORE_TOKENS.include?(kind)
 
         track_module_nesting(token, kind)
@@ -228,7 +236,7 @@ class Pry
 
         if kind == :delimiter
           track_delimiter(token)
-        elsif OPEN_TOKENS.keys.include?(token) && !is_optional_do && !is_singleline_if
+        elsif OPEN_TOKENS.key?(token) && !is_optional_do && !is_singleline_if
           @stack << token
           add_after += 1
         elsif token == OPEN_TOKENS[@stack.last]
@@ -247,20 +255,21 @@ class Pry
         end
       end
 
-      return [remove_before, add_after]
+      [remove_before, add_after]
     end
 
-    # If the code just before an "if" or "while" token on a line looks like the end of a statement,
-    # then we want to treat that "if" as a singleline, not multiline statement.
+    # If the code just before an "if" or "while" token on a line looks like the
+    # end of a statement, then we want to treat that "if" as a singleline, not
+    # multiline statement.
     def end_of_statement?(last_token, last_kind)
-      (last_token =~ /^[)\]}\/]$/ || STATEMENT_END_TOKENS.include?(last_kind))
+      (last_token =~ %r{^[)\]\}/]$} || STATEMENT_END_TOKENS.include?(last_kind))
     end
 
     # Are we currently in the middle of a string literal.
     #
-    # This is used to determine whether to re-indent a given line, we mustn't re-indent
-    # within string literals because to do so would actually change the value of the
-    # String!
+    # This is used to determine whether to re-indent a given line, we mustn't
+    # re-indent within string literals because to do so would actually change
+    # the value of the String!
     #
     # @return Boolean
     def in_string?
@@ -272,16 +281,17 @@ class Pry
     # @param [String] string The Ruby to lex
     # @return [Array] An Array of pairs of [token_value, token_type]
     def tokenize(string)
-      tokens = CodeRay.scan(string, :ruby)
+      tokens = SyntaxHighlighter.tokenize(string)
       tokens = tokens.tokens.each_slice(2) if tokens.respond_to?(:tokens) # Coderay 1.0.0
       tokens.to_a
     end
 
     # Update the internal state about what kind of strings are open.
     #
-    # Most of the complication here comes from the fact that HEREDOCs can be nested. For
-    # normal strings (which can't be nested) we assume that CodeRay correctly pairs
-    # open-and-close delimiters so we don't bother checking what they are.
+    # Most of the complication here comes from the fact that HEREDOCs can be
+    # nested. For normal strings (which can't be nested) we assume that CodeRay
+    # correctly pairs open-and-close delimiters so we don't bother checking what
+    # they are.
     #
     # @param [String] token The token (of type :delimiter)
     def track_delimiter(token)
@@ -292,11 +302,7 @@ class Pry
       when @close_heredocs[@heredoc_queue.first]
         @heredoc_queue.shift
       else
-        if @string_start
-          @string_start = nil
-        else
-          @string_start = token
-        end
+        @string_start = @string_start ? nil : token
       end
     end
 
@@ -312,7 +318,7 @@ class Pry
     #
     # @return String
     def open_delimiters_line
-      "puts #{open_delimiters.join(", ")}"
+      "puts #{open_delimiters.join(', ')}"
     end
 
     # Update the internal state relating to module nesting.
@@ -333,7 +339,7 @@ class Pry
     # @param [String] token  a token from Coderay
     # @param [Symbol] kind  the kind of that token
     def track_module_nesting(token, kind)
-      if kind == :keyword && (token == "class" || token == "module")
+      if kind == :keyword && %w[class module].include?(token)
         @module_nesting << [token, nil]
         @awaiting_class = true
       elsif @awaiting_class
@@ -358,9 +364,7 @@ class Pry
     # @param [String] token  a token from Coderay
     # @param [Symbol] kind  the kind of that token
     def track_module_nesting_end(token, kind = :keyword)
-      if kind == :keyword && (token == "class" || token == "module")
-        @module_nesting.pop
-      end
+      @module_nesting.pop if kind == :keyword && %w[class module].include?(token)
     end
 
     # Return a list of strings which can be used to re-construct the Module.nesting at
@@ -391,7 +395,7 @@ class Pry
       line_to_measure = Pry::Helpers::Text.strip_color(prompt) << code
       whitespace = ' ' * overhang
 
-      cols = Terminal.width!
+      cols = @pry_instance.output.width
       lines = cols == 0 ? 1 : (line_to_measure.length / cols + 1).to_i
 
       if Helpers::Platform.windows_ansi?
