@@ -1,9 +1,13 @@
+# frozen_string_literal: true
+
 class Pry
   class Method
     class Patcher
       attr_accessor :method
 
+      # rubocop:disable Style/ClassVars
       @@source_cache = {}
+      # rubocop:enable Style/ClassVars
 
       def initialize(method)
         @method = method
@@ -51,9 +55,12 @@ class Pry
           alias_method method.name, method.original_name
           alias_method method.original_name, temp_name
         end
-
       ensure
-        method.send(:remove_method, temp_name) rescue nil
+        begin
+          method.send(:remove_method, temp_name)
+        rescue StandardError
+          nil
+        end
       end
 
       # Update the definition line so that it can be eval'd directly on the Method's
@@ -72,7 +79,9 @@ class Pry
         if line =~ /\Adef (?:.*?\.)?#{Regexp.escape(method.original_name)}(?=[\(\s;]|$)/
           "def #{method.original_name}#{$'}"
         else
-          raise CommandError, "Could not find original `def #{method.original_name}` line to patch."
+          raise CommandError,
+                "Could not find original `def #{method.original_name}` line " \
+                "to patch."
         end
       end
 
@@ -94,7 +103,7 @@ class Pry
       def wrap_for_owner(source)
         Pry.current[:pry_owner] = method.owner
         owner_source = definition_for_owner(source)
-        visibility_fix = "#{method.visibility.to_s} #{method.name.to_sym.inspect}"
+        visibility_fix = "#{method.visibility} #{method.name.to_sym.inspect}"
         "Pry.current[:pry_owner].class_eval do; #{owner_source}\n#{visibility_fix}\nend"
       end
 
@@ -113,7 +122,7 @@ class Pry
       def wrap_for_nesting(source)
         nesting = Pry::Code.from_file(method.source_file).nesting_at(method.source_line)
 
-        (nesting + [source] + nesting.map{ "end" } + [""]).join(";")
+        (nesting + [source] + nesting.map { "end" } + [""]).join(";")
       rescue Pry::Indent::UnparseableNestingError
         source
       end
