@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class Pry
   class Method
     # This class is responsible for locating the *real* `Pry::Method`
@@ -6,10 +8,11 @@ class Pry
     # Given a `Binding` from inside a method and a 'seed' Pry::Method object,
     # there are primarily two situations where the seed method doesn't match
     # the Binding:
-    # 1. The Pry::Method is from a subclass 2. The Pry::Method represents a method of the same name
-    # while the original was renamed to something else. For 1. we
-    # search vertically up the inheritance chain,
-    # and for 2. we search laterally along the object's method table.
+    # 1. The Pry::Method is from a subclass
+    # 2. The Pry::Method represents a method of the same name while the original
+    # was renamed to something else. For 1. we search vertically up the
+    # inheritance chain, and for 2. we search laterally along the object's
+    # method table.
     #
     # When we locate the method that matches the Binding we wrap it in
     # Pry::Method and return it, or return nil if we fail.
@@ -21,20 +24,25 @@ class Pry
         # must commence a search.
         #
         # @param [Pry::Method] method
-        # @param [Binding] b
+        # @param [Binding] binding
         # @return [Boolean]
-        def normal_method?(method, b)
-          if method and method.source_file and method.source_range
-            binding_file, binding_line = b.eval('__FILE__'), b.eval('__LINE__')
-            File.expand_path(method.source_file) == File.expand_path(binding_file) and
-            method.source_range.include?(binding_line)
+        def normal_method?(method, binding)
+          if method && method.source_file && method.source_range
+            if binding.respond_to?(:source_location)
+              binding_file, binding_line = binding.source_location
+            else
+              binding_file = binding.eval('__FILE__')
+              binding_line = binding.eval('__LINE__')
+            end
+            (File.expand_path(method.source_file) == File.expand_path(binding_file)) &&
+              method.source_range.include?(binding_line)
           end
-        rescue
+        rescue StandardError
           false
         end
 
-        def weird_method?(method, b)
-          not normal_method?(method, b)
+        def weird_method?(method, binding)
+          !normal_method?(method, binding)
         end
       end
 
@@ -45,12 +53,13 @@ class Pry
       # @param [Binding] target The Binding that captures the method
       #   we want to locate.
       def initialize(method, target)
-        @method, @target = method, target
+        @method = method
+        @target = target
       end
 
       # @return [Pry::Method, nil] The Pry::Method that matches the
       #   given binding.
-      def get_method
+      def find_method
         find_method_in_superclass || find_renamed_method
       end
 
@@ -58,7 +67,7 @@ class Pry
       #   This usually happens when the method captured by the Binding
       #   has been subsequently deleted.
       def lost_method?
-        !!(get_method.nil? && renamed_method_source_location)
+        !!(find_method.nil? && renamed_method_source_location)
       end
 
       private
@@ -77,47 +86,59 @@ class Pry
       end
 
       def target_file
-        pry_file? ? target.eval('__FILE__') : File.expand_path(target.eval('__FILE__'))
+        file =
+          if target.respond_to?(:source_location)
+            target.source_location.first
+          else
+            target.eval('__FILE__')
+          end
+        pry_file? ? file : File.expand_path(file)
       end
 
       def target_line
-        target.eval('__LINE__')
+        if target.respond_to?(:source_location)
+          target.source_location.last
+        else
+          target.eval('__LINE__')
+        end
       end
 
       def pry_file?
-        Pry.eval_path == target.eval('__FILE__')
+        file =
+          if target.respond_to?(:source_location)
+            target.source_location.first
+          else
+            target.eval('__FILE__')
+          end
+        Pry.eval_path == file
       end
 
-      # it's possible in some cases that the method we find by this approach is a sub-method of
-      # the one we're currently in, consider:
+      # it's possible in some cases that the method we find by this approach is
+      # a sub-method of the one we're currently in, consider:
       #
       # class A; def b; binding.pry; end; end
       # class B < A; def b; super; end; end
       #
-      # Given that we can normally find the source_range of methods, and that we know which
-      # __FILE__ and __LINE__ the binding is at, we can hope to disambiguate these cases.
+      # Given that we can normally find the source_range of methods, and that we
+      # know which __FILE__ and __LINE__ the binding is at, we can hope to
+      # disambiguate these cases.
       #
-      # This obviously won't work if the source is unavaiable for some reason, or if both
-      # methods have the same __FILE__ and __LINE__.
+      # This obviously won't work if the source is unavaiable for some reason,
+      # or if both methods have the same __FILE__ and __LINE__.
       #
       # @return [Pry::Method, nil] The Pry::Method representing the
       #   superclass method.
       def find_method_in_superclass
         guess = method
-        if skip_superclass_search?
-          return guess
-        end
+        return guess if skip_superclass_search?
 
         while guess
           # needs rescue if this is a Disowned method or a C method or something...
           # TODO: Fix up the exception handling so we don't need a bare rescue
-          if normal_method?(guess)
-            return guess
-          elsif guess != guess.super
-            guess = guess.super
-          else
-            break
-          end
+          return guess if normal_method?(guess)
+          break if guess == guess.super
+
+          guess = guess.super
         end
 
         # Uhoh... none of the methods in the chain had the right `__FILE__` and
@@ -133,22 +154,23 @@ class Pry
       # @return [Pry::Method, nil] The Pry::Method representing the
       #   renamed method
       def find_renamed_method
-        return if !valid_file?(target_file)
+        return unless valid_file?(target_file)
 
         alias_name = all_methods_for(target_self).find do |v|
-          expanded_source_location(target_self.method(v).source_location) == renamed_method_source_location
+          location = target_self.method(v).source_location
+          expanded_source_location(location) == renamed_method_source_location
         end
 
         alias_name && Pry::Method(target_self.method(alias_name))
       end
 
-      def expanded_source_location(sl)
-        return if !sl
+      def expanded_source_location(source_location)
+        return unless source_location
 
         if pry_file?
-          sl
+          source_location
         else
-          [File.expand_path(sl.first), sl.last]
+          [File.expand_path(source_location.first), source_location.last]
         end
       end
 
@@ -160,14 +182,16 @@ class Pry
       # @return [Array<String, Fixnum>] The `source_location` of the
       #   renamed method
       def renamed_method_source_location
-        return @original_method_source_location if defined?(@original_method_source_location)
+        if defined?(@original_method_source_location)
+          return @original_method_source_location
+        end
 
         source_index = lines_for_file(target_file)[0..(target_line - 1)].rindex do |v|
           Pry::Method.method_definition?(method.name, v)
         end
 
-        @original_method_source_location = source_index &&
-          [target_file, index_to_line_number(source_index)]
+        @original_method_source_location =
+          source_index && [target_file, index_to_line_number(source_index)]
       end
 
       def index_to_line_number(index)
