@@ -1,4 +1,4 @@
-require 'pry/helpers/documentation_helpers'
+# frozen_string_literal: true
 
 class Pry
   class WrappedModule
@@ -12,11 +12,11 @@ class Pry
 
       # @return [String] The file where the module definition is located.
       attr_reader :file
-      alias_method :source_file, :file
+      alias source_file file
 
       # @return [Fixnum] The line where the module definition is located.
       attr_reader :line
-      alias_method :source_line, :line
+      alias source_line line
 
       # Methods to delegate to associated `Pry::WrappedModule
       # instance`.
@@ -40,8 +40,12 @@ class Pry
 
         if number_of_candidates <= 0
           raise CommandError, "Cannot find a definition for #{name} module!"
-        elsif rank > (number_of_candidates - 1)
-          raise CommandError, "No such module candidate. Allowed candidates range is from 0 to #{number_of_candidates - 1}"
+        end
+
+        if rank > (number_of_candidates - 1)
+          raise CommandError,
+                "No such module candidate. Allowed candidates range is " \
+                "from 0 to #{number_of_candidates - 1}"
         end
 
         @source = @source_location = nil
@@ -56,7 +60,9 @@ class Pry
         return nil if file.nil?
         return @source if @source
 
-        @source ||= strip_leading_whitespace(Pry::Code.from_file(file).expression_at(line, number_of_lines_in_first_chunk))
+        @source ||= strip_leading_whitespace(
+          Pry::Code.from_file(file).expression_at(line, number_of_lines_in_first_chunk)
+        )
       end
 
       # @raise [Pry::CommandError] If documentation cannot be found.
@@ -74,7 +80,7 @@ class Pry
         return @source_location if @source_location
 
         file, line = first_method_source_location
-        return nil if !file.is_a?(String)
+        return nil unless file.is_a?(String)
 
         @source_location = [file, first_line_of_module_definition(file, line)]
       rescue Pry::RescuableException
@@ -97,7 +103,7 @@ class Pry
 
       def class_regexes
         mod_type_string = wrapped.class.to_s.downcase
-        [/^\s*#{mod_type_string}\s+(?:(?:\w*)::)*?#{wrapped.name.split(/::/).last}/,
+        [/(^|=)\s*#{mod_type_string}\s+(?:(?:\w*)::)*?#{wrapped.name.split(/::/).last}/,
          /^\s*(::)?#{wrapped.name.split(/::/).last}\s*?=\s*?#{wrapped.class}/,
          /^\s*(::)?#{wrapped.name.split(/::/).last}\.(class|instance)_eval/]
       end
@@ -113,14 +119,15 @@ class Pry
       # @return [Array] The source location of the last method in this
       #   candidate's module definition.
       def last_method_source_location
-        @end_method_source_location ||= method_candidates[@rank].last.source_location
+        @last_method_source_location ||= method_candidates[@rank].last.source_location
       end
 
-      # Return the number of lines between the start of the class definition
-      # and the start of the last method. We use this value so we can
-      # quickly grab these lines from the file (without having to
-      # check each intervening line for validity, which is expensive) speeding up source extraction.
-      # @return [Fixum] Number of lines.
+      # Return the number of lines between the start of the class definition and
+      # the start of the last method. We use this value so we can quickly grab
+      # these lines from the file (without having to check each intervening line
+      # for validity, which is expensive) speeding up source extraction.
+      #
+      # @return [Integer] number of lines.
       def number_of_lines_in_first_chunk
         end_method_line = last_method_source_location.last
 
