@@ -1,12 +1,16 @@
+# frozen_string_literal: true
+
 require 'pathname'
-require_relative '../helper'
+require 'tempfile'
 
 describe "edit" do
   before do
     @old_editor = Pry.config.editor
     @file = @line = @contents = nil
     Pry.config.editor = lambda do |file, line|
-      @file = file; @line = line; @contents = File.read(@file)
+      @file = file
+      @line = line
+      @contents = File.read(@file)
       nil
     end
   end
@@ -37,7 +41,8 @@ describe "edit" do
     it "should not allow patching any known kind of file" do
       ["file.rb", "file.c", "file.py", "file.yml", "file.gemspec",
        "/tmp/file", "\\\\Temp\\\\file"].each do |file|
-        expect { pry_eval "edit -p #{file}" }.to raise_error(NotImplementedError, /Cannot yet patch false objects!/)
+        expect { pry_eval "edit -p #{file}" }
+          .to raise_error(NotImplementedError, /Cannot yet patch false objects!/)
       end
     end
 
@@ -45,7 +50,7 @@ describe "edit" do
       pry_eval 'edit lib/pry.rb'
       expect(@file).to eq File.expand_path('lib/pry.rb')
 
-      pry_eval "edit #@tf_path"
+      pry_eval "edit #{@tf_path}"
       expect(@file).to eq @tf_path
     end
 
@@ -67,19 +72,21 @@ describe "edit" do
     it "works with files that contain blanks in their names" do
       tf_path = File.join(File.dirname(@tf_path), 'swoop and doop.rb')
       FileUtils.touch(tf_path)
-      pry_eval "edit #{ tf_path }"
+      pry_eval "edit #{tf_path}"
       expect(@file).to eq tf_path
       FileUtils.rm(tf_path)
     end
 
     if respond_to?(:require_relative, true)
       it "should work with require relative" do
-        Pry.config.editor = lambda { |file, line|
+        Pry.config.editor = lambda { |file, _line|
           File.open(file, 'w') { |f| f << 'require_relative "baz.rb"' }
-          File.open(file.gsub('bar.rb', 'baz.rb'), 'w') { |f| f << "Pad.required = true; FileUtils.rm(__FILE__)" }
+          File.open(file.gsub('bar.rb', 'baz.rb'), 'w') do |f|
+            f << "Pad.required = true; FileUtils.rm(__FILE__)"
+          end
           nil
         }
-        pry_eval "edit #@tf_path"
+        pry_eval "edit #{@tf_path}"
         expect(Pad.required).to eq true
       end
     end
@@ -87,7 +94,7 @@ describe "edit" do
     describe do
       before do
         Pad.counter = 0
-        Pry.config.editor = lambda { |file, line|
+        Pry.config.editor = lambda { |file, _line|
           File.open(file, 'w') { |f| f << "Pad.counter = Pad.counter + 1" }
           nil
         }
@@ -142,7 +149,9 @@ describe "edit" do
       before do
         @reloading = nil
         Pry.config.editor = lambda do |file, line, reloading|
-          @file = file; @line = line; @reloading = reloading
+          @file = file
+          @line = line
+          @reloading = reloading
           nil
         end
       end
@@ -163,7 +172,9 @@ describe "edit" do
           @pry.last_exception = exception
         end
 
-        def last_exception; @pry.last_exception; end
+        def last_exception
+          @pry.last_exception
+        end
       end
     end
 
@@ -186,7 +197,7 @@ describe "edit" do
       end
 
       it "should reload the file" do
-        Pry.config.editor = lambda { |file, line|
+        @t.pry.config.editor = lambda { |file, _line|
           File.open(file, 'w') { |f| f << "FOO = 'BAR'" }
           nil
         }
@@ -210,17 +221,17 @@ describe "edit" do
         Pad.le = @t.last_exception
         redirect_pry_io(InputTester.new("def broken_method", "binding.pry", "end",
                                         "broken_method",
-                                        "_pry_.last_exception = Pad.le",
+                                        "pry_instance.last_exception = Pad.le",
                                         "edit --ex -n", "exit-all", "exit-all")) do
           Object.new.pry
         end
 
-        expect(source_location).to eq [@path, 3]
+        expect(source_location).to contain_exactly(%r{(/private)?#{@path}}, 3)
         Pad.clear
       end
 
       it "should not reload the file if -n is passed" do
-        Pry.config.editor = lambda { |file, line|
+        Pry.config.editor = lambda { |file, _line|
           File.open(file, 'w') { |f| f << "FOO2 = 'BAZ'" }
           nil
         }
@@ -235,7 +246,7 @@ describe "edit" do
       describe "with --patch" do
         # Original source code must be untouched.
         it "should apply changes only in memory (monkey patching)" do
-          Pry.config.editor = lambda { |file, line|
+          @t.pry.config.editor = lambda { |file, _line|
             File.open(file, 'w') { |f| f << "FOO3 = 'PIYO'" }
             @patched_def = File.open(file, 'r').read
             nil
@@ -256,7 +267,7 @@ describe "edit" do
 
     describe "with --ex NUM" do
       before do
-        Pry.config.editor = proc do |file, line|
+        @t.pry.config.editor = proc do |file, line|
           @__ex_file__ = file
           @__ex_line__ = line
           nil
@@ -332,7 +343,7 @@ describe "edit" do
     end
 
     it "should evaluate the expression" do
-      Pry.config.editor = lambda { |file, line|
+      @t.pry.config.editor = lambda { |file, _line|
         File.open(file, 'w') { |f| f << "'FOO'\n" }
         nil
       }
@@ -341,7 +352,7 @@ describe "edit" do
     end
 
     it "should ignore -n for tempfiles" do
-      Pry.config.editor = lambda { |file, line|
+      @t.pry.config.editor = lambda { |file, _line|
         File.open(file, 'w') { |f| f << "'FOO'\n" }
         nil
       }
@@ -350,7 +361,7 @@ describe "edit" do
     end
 
     it "should not evaluate a file with -n" do
-      Pry.config.editor = lambda { |file, line|
+      @t.pry.config.editor = lambda { |file, _line|
         File.open(file, 'w') { |f| f << "'FOO'\n" }
         nil
       }
@@ -365,10 +376,10 @@ describe "edit" do
 
     it "should write the evaluated command to history" do
       quote = 'history repeats itself, first as tradegy...'
-      Pry.config.editor = lambda { |file, line|
-        File.open(file, 'w') { |f|
+      @t.pry.config.editor = lambda { |file, _line|
+        File.open(file, 'w') do |f|
           f << quote
-        }
+        end
         nil
       }
       @t.process_command 'edit'
@@ -398,23 +409,28 @@ describe "edit" do
     end
 
     it "should not work with a filename" do
-      expect { pry_eval 'edit ruby.rb -i' }.to raise_error(Pry::CommandError, /Only one of --ex, --temp, --in, --method and FILE/)
+      expect { pry_eval 'edit ruby.rb -i' }.to raise_error(
+        Pry::CommandError, /Only one of --ex, --temp, --in, --method and FILE/
+      )
     end
 
     it "should not work with nonsense" do
-      expect { pry_eval 'edit --in three' }.to raise_error(Pry::CommandError, /Not a valid range: three/)
+      expect { pry_eval 'edit --in three' }.to raise_error(
+        Pry::CommandError, /Not a valid range: three/
+      )
     end
   end
 
   describe 'when editing a method by name' do
     def use_editor(tester, options)
-      tester.pry.config.editor = lambda do |filename, line|
+      tester.pry.config.editor = lambda do |filename, _line|
         File.open(filename, 'w') { |f| f.write options.fetch(:replace_all) }
         nil
       end
       tester
     end
 
+    # rubocop:disable Style/SingleLineMethods
     it 'uses patch editing on methods that were previously patched' do
       # initial definition
       tester   = pry_tester binding
@@ -436,6 +452,7 @@ describe "edit" do
       # original file is unchanged
       expect(File.readlines(filename)[line - 1].strip).to eq 'def m; 1; end'
     end
+    # rubocop:enable Style/SingleLineMethods
 
     it 'can repeatedly edit methods that were defined in the console' do
       # initial definition
@@ -460,8 +477,8 @@ describe "edit" do
       before do
         Object.remove_const :X if defined? ::X
         Object.remove_const :A if defined? ::A
-        @tempfile = (Tempfile.new(['pry', '.rb']))
-        @tempfile.puts <<-EOS
+        @tempfile = Tempfile.new(['pry', '.rb'])
+        @tempfile.puts(<<-CLASSES)
         module A
           def a
             :yup
@@ -501,7 +518,7 @@ describe "edit" do
             end
           end
         end
-        EOS
+        CLASSES
         @tempfile.flush
         load @tempfile.path
 
@@ -516,46 +533,49 @@ describe "edit" do
         before do
           @file = @line = @contents = nil
           Pry.config.editor = lambda do |file, line|
-            @file = file; @line = line
+            @file = file
+            @line = line
             nil
           end
         end
 
+        # Workaround for https://github.com/jruby/jruby/issues/5436.
+        let(:expected_file) { %r{(/private)?#{@tempfile_path}} }
+
         it "should correctly find a class method" do
           pry_eval 'edit X.x'
-
-          expect(@file).to eq @tempfile_path
+          expect(@file).to match(expected_file)
           expect(@line).to eq 14
         end
 
         it "should correctly find an instance method" do
           pry_eval 'edit X#x'
-          expect(@file).to eq @tempfile_path
+          expect(@file).to match(expected_file)
           expect(@line).to eq 18
         end
 
         it "should correctly find a method on an instance" do
           pry_eval 'x = X.new', 'edit x.x'
-          expect(@file).to eq @tempfile_path
+          expect(@file).to match(expected_file)
           expect(@line).to eq 18
         end
 
         it "should correctly find a method from a module" do
           pry_eval 'edit X#a'
-          expect(@file).to eq @tempfile_path
+          expect(@file).to match(expected_file)
           expect(@line).to eq 2
         end
 
         it "should correctly find an aliased method" do
           pry_eval 'edit X#c'
-          expect(@file).to eq @tempfile_path
+          expect(@file).to match(expected_file)
           expect(@line).to eq 22
         end
       end
 
       describe 'with -p' do
         before do
-          Pry.config.editor = lambda do |file, line|
+          Pry.config.editor = lambda do |file, _line|
             lines = File.read(file).lines.to_a
             lines[1] = if lines[2] =~ /end/
                          ":maybe\n"
@@ -572,10 +592,7 @@ describe "edit" do
 
         it "should successfully replace a class method" do
           pry_eval 'edit -p X.x'
-
-          class << X
-            X.method(:x).owner.should == self
-          end
+          expect(X.method(:x).owner).to eq class << X; self end
           expect(X.method(:x).receiver).to eq X
           expect(X.x).to eq :maybe
         end
@@ -650,7 +667,7 @@ describe "edit" do
 
           it "should work for a class method" do
             def_before, def_after =
-              apply_monkey_patch(X.method(:x), "#@edit X.x")
+              apply_monkey_patch(X.method(:x), "#{@edit} X.x")
 
             expect(def_before).to   eq ':double_yup'
             expect(def_after).to    eq ':double_yup'
@@ -659,7 +676,7 @@ describe "edit" do
 
           it "should work for an instance method" do
             def_before, def_after =
-              apply_monkey_patch(X.instance_method(:x), "#@edit X#x")
+              apply_monkey_patch(X.instance_method(:x), "#{@edit} X#x")
 
             expect(def_before).to   eq ':nope'
             expect(def_after).to    eq ':nope'
@@ -667,8 +684,9 @@ describe "edit" do
           end
 
           it "should work for a method on an instance" do
-            def_before, def_after =
-              apply_monkey_patch(X.instance_method(:x), 'instance = X.new', "#@edit instance.x")
+            def_before, def_after = apply_monkey_patch(
+              X.instance_method(:x), 'instance = X.new', "#{@edit} instance.x"
+            )
 
             expect(def_before).to   eq ':nope'
             expect(def_after).to    eq ':nope'
@@ -677,7 +695,7 @@ describe "edit" do
 
           it "should work for a method from a module" do
             def_before, def_after =
-              apply_monkey_patch(X.instance_method(:a), "#@edit X#a")
+              apply_monkey_patch(X.instance_method(:a), "#{@edit} X#a")
 
             expect(def_before).to   eq ':yup'
             expect(def_after).to    eq ':yup'
@@ -686,7 +704,7 @@ describe "edit" do
 
           it "should work for a method with a question mark" do
             def_before, def_after =
-              apply_monkey_patch(X.instance_method(:y?), "#@edit X#y?")
+              apply_monkey_patch(X.instance_method(:y?), "#{@edit} X#y?")
 
             expect(def_before).to   eq ':because'
             expect(def_after).to    eq ':because'
@@ -695,7 +713,7 @@ describe "edit" do
 
           it "should work with nesting" do
             def_before, def_after =
-              apply_monkey_patch(X::B.instance_method(:foo), "#@edit X::B#foo")
+              apply_monkey_patch(X::B.instance_method(:foo), "#{@edit} X::B#foo")
 
             expect(def_before).to   eq '_foo = :possibly'
             expect(def_after).to    eq '_foo = :possibly'
@@ -706,9 +724,13 @@ describe "edit" do
 
       describe 'on an aliased method' do
         before do
-          Pry.config.editor = lambda do |file, line|
+          Pry.config.editor = lambda do |file, _line|
             lines = File.read(file).lines.to_a
+
+            # rubocop:disable Lint/InterpolationCheck
             lines[1] = '"#{super}aa".to_sym' + "\n"
+            # rubocop:enable Lint/InterpolationCheck
+
             File.open(file, 'w') do |f|
               f.write(lines.join)
             end
@@ -717,14 +739,11 @@ describe "edit" do
         end
 
         it "should change the alias, but not the original, without breaking super" do
-          $x = :bebe
           pry_eval 'edit -p X#c'
 
           expect(Pry::Method.from_str("X#c").alias?).to eq true
-
           expect(X.new.b).to eq :kinda
           expect(X.new.c).to eq :kindaaa
-          $x = nil
         end
       end
 
@@ -732,7 +751,9 @@ describe "edit" do
         before do
           @file = @line = @reloading = nil
           Pry.config.editor = lambda do |file, line, reloading|
-            @file = file; @line = line; @reloading = reloading
+            @file = file
+            @line = line
+            @reloading = reloading
             nil
           end
         end
@@ -751,11 +772,13 @@ describe "edit" do
     before do
       @t = pry_tester
       class BinkyWink
-        eval %{
+        # rubocop:disable Style/EvalWithLocation
+        eval <<-RUBY
           def m1
             binding
           end
-        }
+        RUBY
+        # rubocop:enable Style/EvalWithLocation
 
         def m2
           _foo = :jeremy_jones
@@ -785,11 +808,13 @@ describe "edit" do
       end
 
       t = pry_tester(BinkyWink.new.m1)
-      expect { t.process_command "edit -m -n" }.to raise_error(Pry::CommandError, /Cannot find a file for/)
+      expect { t.process_command "edit -m -n" }
+        .to raise_error(Pry::CommandError, /Cannot find a file for/)
     end
 
     it 'errors when a filename arg is passed with --method' do
-      expect { @t.process_command "edit -m Pry#repl" }.to raise_error(Pry::CommandError, /Only one of/)
+      expect { @t.process_command "edit -m Pry#repl" }
+        .to raise_error(Pry::CommandError, /Only one of/)
     end
   end
 
@@ -797,10 +822,9 @@ describe "edit" do
     before do
       @t = pry_tester
       class TrinkyDink
-        eval %{
-          def m
-          end
-        }
+        # rubocop:disable Style/EvalWithLocation
+        eval('def m; end')
+        # rubocop:enable Style/EvalWithLocation
       end
     end
 
@@ -809,7 +833,8 @@ describe "edit" do
     end
 
     it 'should display a nice error message when cannot open a file' do
-      expect { @t.process_command "edit TrinkyDink#m" }.to raise_error(Pry::CommandError, /Cannot find a file for/)
+      expect { @t.process_command "edit TrinkyDink#m" }
+        .to raise_error(Pry::CommandError, /Cannot find a file for/)
     end
   end
 end
