@@ -1,4 +1,4 @@
-require_relative '../helper'
+# frozen_string_literal: true
 
 describe "hist" do
   before do
@@ -44,7 +44,7 @@ describe "hist" do
     @hist.push "cd 2"
 
     @t.eval("hist --replay 0..2")
-    stack = @t.eval("Pad.stack = _pry_.binding_stack.dup")
+    stack = @t.eval("Pad.stack = pry_instance.binding_stack.dup")
     expect(stack.map { |b| b.eval("self") }).to eq [TOPLEVEL_BINDING.eval("self"), 1, 2]
   end
 
@@ -132,6 +132,15 @@ describe "hist" do
     expect(out).to match(/b\n\d+:.*c\n\d+:.*d/)
   end
 
+  it 'should show lines between offsets A and B with the --show switch' do
+    ("a".."f").each do |v|
+      @hist.push v
+    end
+
+    out = @t.eval 'hist --show -4..-2'
+    expect(out).to eq "3: c\n4: d\n5: e\n"
+  end
+
   it "should store a call with `--replay` flag" do
     @t.eval ":banzai"
     @t.eval "hist --replay 1"
@@ -148,11 +157,17 @@ describe "hist" do
     expect(output).to eq "1: :banzai\n2: :geronimo\n3: :huzzah\n4: hist --replay 1..3\n"
   end
 
-  it "should raise CommandError when index of `--replay` points out to another `hist --replay`" do
+  it(
+    "raises CommandError when index of `--replay` points out to another " \
+    "`hist --replay`"
+  ) do
     @t.eval ":banzai"
     @t.eval "hist --replay 1"
 
-    expect { @t.eval "hist --replay 2" }.to raise_error(Pry::CommandError, /Replay index 2 points out to another replay call: `hist --replay 1`/)
+    expect { @t.eval "hist --replay 2" }.to raise_error(
+      Pry::CommandError,
+      /Replay index 2 points out to another replay call: `hist --replay 1`/
+    )
   end
 
   it "should disallow execution of `--replay <i>` when CommandError raised" do
@@ -172,13 +187,13 @@ describe "hist" do
 
   describe "sessions" do
     before do
-      @old_file = Pry.config.history.file
-      Pry.config.history.file = File.expand_path('spec/fixtures/pry_history')
+      @old_file = Pry.config.history_file
+      Pry.config.history_file = File.expand_path('spec/fixtures/pry_history')
       @hist.load
     end
 
     after do
-      Pry.config.history.file = @old_file
+      Pry.config.history_file = @old_file
     end
 
     it "displays history only for current session" do
@@ -198,7 +213,7 @@ describe "hist" do
     end
 
     it "should not display histignore words in history" do
-      Pry.config.history.histignore = [
+      Pry.config.history_ignorelist = [
         "well",
         "hello",
         "beautiful",
