@@ -1,9 +1,8 @@
+# frozen_string_literal: true
+
 # This command needs a TONNE more tests for it, but i can't figure out
 # how to do them yet, and i really want to release. Sorry. Someone
 # come along and do a better job.
-
-require_relative '../helper'
-
 describe "play" do
   before do
     @o = Object.new
@@ -18,14 +17,14 @@ describe "play" do
       # end
 
       # describe "integer" do
-      #   it "should process one line from _pry_.last_file" do
+      #   it "should process one line from pry_instance.last_file" do
       #     @t.process_command 'play --lines 1', @eval_str
       #     @eval_str.should =~ /bing = :bing\n/
       #   end
       # end
 
       # describe "range" do
-      #   it "should process multiple lines at once from _pry_.last_file" do
+      #   it "should process multiple lines at once from pry_instance.last_file" do
       #     @t.process_command 'play --lines 1..3', @eval_str
       #     [/bing = :bing\n/, /bang = :bang\n/, /bong = :bong\n/].each { |str|
       #       @eval_str.should =~ str
@@ -38,6 +37,7 @@ describe "play" do
     it 'should play a file' do
       @t.process_command 'play spec/fixtures/whereami_helper.rb'
       expect(@t.eval_string).to eq unindent(<<-STR)
+        # frozen_string_literal: true
         # rubocop:disable Layout/EmptyLineBetweenDefs
         class Cor
           def a; end
@@ -51,16 +51,18 @@ describe "play" do
 
     it 'should output file contents with print option' do
       @t.process_command 'play --print spec/fixtures/whereami_helper.rb'
-      expect(@t.last_output).to eq unindent(<<-STR)
-        1: # rubocop:disable Layout/EmptyLineBetweenDefs
-        2: class Cor
-        3:   def a; end
-        4:   def b; end
-        5:   def c; end
-        6:   def d; end
-        7: end
-        8: # rubocop:enable Layout/EmptyLineBetweenDefs
-      STR
+      expect(@t.last_output).to eq(
+        " 1: \# frozen_string_literal: true\n" \
+        " 2: \n" \
+        " 3: \# rubocop:disable Layout/EmptyLineBetweenDefs\n" \
+        " 4: class Cor\n" \
+        " 5:   def a; end\n" \
+        " 6:   def b; end\n" \
+        " 7:   def c; end\n" \
+        " 8:   def d; end\n" \
+        " 9: end\n" \
+        "10: \# rubocop:enable Layout/EmptyLineBetweenDefs\n"
+      )
     end
   end
 
@@ -106,7 +108,8 @@ describe "play" do
     end
 
     it 'has pretty error messages when -d cant find object' do
-      expect { @t.process_command "play -d sdfsdf" }.to raise_error(Pry::CommandError, /Cannot locate/)
+      expect { @t.process_command "play -d sdfsdf" }
+        .to raise_error(Pry::CommandError, /Cannot locate/)
     end
 
     it 'should play a method (a single line)' do
@@ -158,10 +161,13 @@ describe "play" do
     describe "play -i" do
       it 'should play multi-ranged input expressions' do
         a = b = c = d = e = 0
-        redirect_pry_io(InputTester.new('a += 1', 'b += 1',
-                                        'c += 1', 'd += 1', 'e += 1',
-                                        "play -i 1..3"), StringIO.new) do
-          binding.pry
+        redirect_pry_io(
+          InputTester.new(
+            'a += 1', 'b += 1', 'c += 1', 'd += 1', 'e += 1', 'play -i 1..3'
+          ),
+          StringIO.new
+        ) do
+          binding.pry # rubocop:disable Lint/Debugger
         end
 
         [a, b, c].all? { |v| expect(v).to eq 2 }
@@ -176,16 +182,16 @@ describe "play" do
 
         def @o.test_method
           @s = [
-            1,2,3,
-            4,5,6
+            1, 2, 3,
+            4, 5, 6
           ]
         end
 
         @t.process_command 'play test_method -e 2'
         expect(@t.eval_string).to eq unindent(<<-STR, 0)
           @s = [
-            1,2,3,
-            4,5,6
+            1, 2, 3,
+            4, 5, 6
           ]
         STR
       end
