@@ -1,4 +1,6 @@
-require_relative '../helper'
+# frozen_string_literal: true
+
+require 'tempfile'
 
 describe "save-file" do
   before do
@@ -45,9 +47,11 @@ describe "save-file" do
 
     it 'should save multi-ranged input expressions' do
       @t.eval ':or_nostrils', ':sucking_up_all_the_oxygen', ':or_whatever',
-      ':baby_ducks', ':cannot_escape'
+              ':baby_ducks', ':cannot_escape'
       @t.eval "save-file -i 1..2 -i 4..5 --to '#{@path}'"
-      expect(File.read(@path)).to eq(":or_nostrils\n:sucking_up_all_the_oxygen\n:baby_ducks\n:cannot_escape\n")
+      expect(File.read(@path)).to eq(
+        ":or_nostrils\n:sucking_up_all_the_oxygen\n:baby_ducks\n:cannot_escape\n"
+      )
     end
   end
 
@@ -72,7 +76,8 @@ describe "save-file" do
       end
 
       it "should display a success message on save" do
-        expect(@t.eval("save-file --to '#{@path}' baby")).to match(/successfully saved/)
+        expect(@t.eval("save-file --to '#{@path}' baby"))
+          .to match(/successfully saved/)
       end
 
       it 'should save a method to a file truncated by --lines' do
