@@ -1,4 +1,6 @@
-require_relative '../helper'
+# frozen_string_literal: true
+
+require 'method_source'
 
 describe "whereami" do
   it 'should work with methods that have been undefined' do
@@ -20,24 +22,25 @@ describe "whereami" do
   it 'should work in objects with no method methods' do
     class Cor
       def blimey!
-        pry_eval(binding, 'whereami').should =~ /Cor[#]blimey!/
+        pry_eval(binding, 'whereami')
       end
 
-      def method; "moo"; end
+      def method
+        "moo"
+      end
     end
-    Cor.new.blimey!
+    expect(Cor.new.blimey!).to match(/Cor[#]blimey!/)
     Object.remove_const(:Cor)
   end
 
   it 'should properly set _file_, _line_ and _dir_' do
     class Cor
       def blimey!
-        pry_eval(binding, 'whereami', '_file_').
-          should == File.expand_path(__FILE__)
+        pry_eval(binding, 'whereami', '_file_')
       end
     end
 
-    Cor.new.blimey!
+    expect(Cor.new.blimey!).to eq File.expand_path(__FILE__)
     Object.remove_const(:Cor)
   end
 
@@ -51,11 +54,11 @@ describe "whereami" do
       class Cor
         prepend Cor2
         def blimey!
-          pry_eval(binding, 'whereami').should =~ /Cor2[#]blimey!/
+          pry_eval(binding, 'whereami')
         end
       end
 
-      Cor.new.blimey!
+      expect(Cor.new.blimey!).to match(/Cor2[#]blimey!/)
 
       Object.remove_const(:Cor)
       Object.remove_const(:Cor2)
@@ -72,12 +75,15 @@ describe "whereami" do
     expect(pry_eval(cor, 'whereami')).to match(/::Kernel.binding [#] omnom/)
   end
 
-  it 'should show description and correct code when __LINE__ and __FILE__ are outside @method.source_location' do
+  it(
+    'shows description and corrects code when __LINE__ and __FILE__ are ' \
+    'outside @method.source_location'
+  ) do
     class Cor
       def blimey!
-        eval <<-END, binding, "spec/fixtures/example.erb", 1
+        eval(<<-WHEREAMI, binding, 'spec/fixtures/example.erb', 1)
           pry_eval(binding, 'whereami')
-        END
+        WHEREAMI
       end
     end
 
@@ -86,16 +92,20 @@ describe "whereami" do
     Object.remove_const(:Cor)
   end
 
-  it 'should show description and correct code when @method.source_location would raise an error' do
+  it(
+    'shows description and corrects code when @method.source_location ' \
+    'would raise an error'
+  ) do
     class Cor
-      eval <<-END, binding, "spec/fixtures/example.erb", 1
+      eval <<-WHEREAMI, binding, "spec/fixtures/example.erb", 1
         def blimey!
           pry_eval(binding, 'whereami')
         end
-      END
+      WHEREAMI
     end
 
-    expect { Cor.instance_method(:blimey!).source }.to raise_error MethodSource::SourceNotFoundError
+    expect { Cor.instance_method(:blimey!).source }
+      .to raise_error MethodSource::SourceNotFoundError
 
     expect(Cor.new.blimey!).to match(/Cor#blimey!.*Look at me/m)
     Object.remove_const(:Cor)
@@ -121,23 +131,25 @@ describe "whereami" do
   #   proc { Cor.new.blimey! }.should.raise(MethodSource::SourceNotFoundError)
 
   #   Pad.tester.last_output.should =~
-  #     /From: not.found.file.erb @ line 7 Cor#blimey!:/
+  #     /From: not.found.file.erb:7 Cor#blimey!/
   #   Object.remove_const(:Cor)
   # end
 
   it 'should show code window (not just method source) if parameter passed to whereami' do
     class Cor
       def blimey!
-        pry_eval(binding, 'whereami 3').should =~ /class Cor/
+        pry_eval(binding, 'whereami 3')
       end
     end
-    Cor.new.blimey!
+    expect(Cor.new.blimey!).to match(/class Cor/)
     Object.remove_const(:Cor)
   end
 
   it 'should show entire method when -m option used' do
-    old_size, Pry.config.default_window_size = Pry.config.default_window_size, 1
-    old_cutoff, Pry::Command::Whereami.method_size_cutoff = Pry::Command::Whereami.method_size_cutoff, 1
+    old_size = Pry.config.default_window_size
+    Pry.config.default_window_size = 1
+    old_cutoff = Pry::Command::Whereami.method_size_cutoff
+    Pry::Command::Whereami.method_size_cutoff = 1
     class Cor
       def blimey!
         @foo = 1
@@ -145,7 +157,8 @@ describe "whereami" do
         pry_eval(binding, 'whereami -m')
       end
     end
-    Pry::Command::Whereami.method_size_cutoff, Pry.config.default_window_size = old_cutoff, old_size
+    Pry::Command::Whereami.method_size_cutoff = old_cutoff
+    Pry.config.default_window_size = old_size
     result = Cor.new.blimey!
     Object.remove_const(:Cor)
     expect(result).to match(/def blimey/)
@@ -184,7 +197,7 @@ describe "whereami" do
       end
 
       class Horse < Cor
-        def pig;end
+        def pig; end
       end
 
       out = Horse.new.blimey!
@@ -197,30 +210,44 @@ describe "whereami" do
 
     it 'should show class when -c option used, and binding is outside a method' do
       class Cor
-        def blimey;end
-
+        extend RSpec::Matchers
+        def blimey; end
         out = pry_eval(binding, 'whereami -c')
-        out.should =~ /class Cor/
-        out.should =~ /blimey/
+        expect(out).to match(/class Cor/)
+        expect(out).to match(/blimey/)
       end
       Object.remove_const(:Cor)
     end
+
+    it 'should show class when -c option used, and beginning of the class is on the' \
+       'same line as another expression' do
+      out = class Cor
+              def blimey; end
+              pry_eval(binding, 'whereami -c')
+            end
+      expect(out).to match(/class Cor/)
+      expect(out).to match(/blimey/)
+      Object.remove_const(:Cor)
+    end
   end
 
   it 'should not show line numbers or marker when -n switch is used' do
     class Cor
       def blimey!
-        out = pry_eval(binding, 'whereami -n')
-        out.should =~ /^\s*def/
-        out.should_not =~ /\=\>/
+        pry_eval(binding, 'whereami -n')
       end
     end
-    Cor.new.blimey!
+    out = Cor.new.blimey!
+    expect(out).to match(/^\s*def/)
+    expect(out).to_not match(/\=\>/)
     Object.remove_const(:Cor)
   end
 
-  it 'should use Pry.config.default_window_size for window size when outside a method context' do
-    old_size, Pry.config.default_window_size = Pry.config.default_window_size, 1
+  it(
+    'uses Pry.config.default_window_size for window size when outside a method context'
+  ) do
+    old_size = Pry.config.default_window_size
+    Pry.config.default_window_size = 1
     _foo = :litella
     _foo = :pig
     out = pry_eval(binding, 'whereami')
