@@ -1,11 +1,16 @@
-require_relative 'helper'
+# frozen_string_literal: true
+
 require "readline" unless defined?(Readline)
 require "pry/input_completer"
 
 def completer_test(bind, pry = nil, assert_flag = true)
-  test = proc { |symbol|
-    expect(Pry::InputCompleter.new(pry || Readline, pry).call(symbol[0..-2], target: Pry.binding_for(bind)).include?(symbol)).to eq(assert_flag)}
-  return proc { |*symbols| symbols.each(&test) }
+  test = proc do |symbol|
+    input = pry || Readline
+    input_completer = Pry::InputCompleter.new(input, pry)
+    completions = input_completer.call(symbol[0..-2], target: Pry.binding_for(bind))
+    expect(completions.include?(symbol)).to eq(assert_flag)
+  end
+  proc { |*symbols| symbols.each(&test) }
 end
 
 describe Pry::InputCompleter do
@@ -14,7 +19,9 @@ describe Pry::InputCompleter do
     #  pry(main)> AMQP::Protocol::Test::ContentOk.name
     #  => :content_ok
     module SymbolyName
-      def self.name; :symboly_name; end
+      def self.name
+        :symboly_name
+      end
     end
 
     @before_completer = Pry.config.completer
@@ -28,11 +35,19 @@ describe Pry::InputCompleter do
 
   it "should not crash if there's a Module that has a symbolic name." do
     skip unless Pry::Helpers::Platform.jruby?
-    expect { Pry::InputCompleter.new(Readline).call "a.to_s.", target: Pry.binding_for(Object.new) }.not_to raise_error
+    expect do
+      Pry::InputCompleter.new(Readline).call(
+        "a.to_s.", target: Pry.binding_for(Object.new)
+      )
+    end.not_to raise_error
   end
 
   it 'should take parenthesis and other characters into account for symbols' do
-    expect { Pry::InputCompleter.new(Readline).call ":class)", target: Pry.binding_for(Object.new) }.not_to raise_error
+    expect do
+      Pry::InputCompleter.new(Readline).call(
+        ":class)", target: Pry.binding_for(Object.new)
+      )
+    end.not_to raise_error
   end
 
   it 'should complete instance variables' do
@@ -43,13 +58,13 @@ describe Pry::InputCompleter do
     object.class.send(:class_variable_set, :'@@number', 10)
 
     # check to see if variables are in scope
-    expect(object.instance_variables.
-      map { |v| v.to_sym }.
-      include?(:'@name')).to eq true
+    expect(object.instance_variables
+      .map(&:to_sym)
+      .include?(:'@name')).to eq true
 
-    expect(object.class.class_variables.
-      map { |v| v.to_sym }.
-      include?(:'@@number')).to eq true
+    expect(object.class.class_variables
+      .map(&:to_sym)
+      .include?(:'@@number')).to eq true
 
     # Complete instance variables.
     b = Pry.binding_for(object)
@@ -86,16 +101,16 @@ describe Pry::InputCompleter do
 
     # Constant
     module Mod
-      remove_const :Con if defined? Con
-      Con = 'Constant'
+      remove_const :CON if defined? CON
+      CON = 'Constant'.freeze
       module Mod2
       end
     end
 
-    completer_test(Mod).call('Con')
+    completer_test(Mod).call('CON')
 
     # Constants or Class Methods
-    completer_test(o).call('Mod::Con')
+    completer_test(o).call('Mod::CON')
 
     # Symbol
     _foo = :symbol
@@ -109,7 +124,8 @@ describe Pry::InputCompleter do
     completer_test(binding).call('o.foo')
 
     # trailing slash
-    expect(Pry::InputCompleter.new(Readline).call('Mod2/', target: Pry.binding_for(Mod)).include?('Mod2/')).to eq(true)
+    expect(Pry::InputCompleter.new(Readline).call('Mod2/', target: Pry.binding_for(Mod))
+      .include?('Mod2/')).to eq(true)
   end
 
   it 'should complete for arbitrary scopes' do
@@ -118,10 +134,10 @@ describe Pry::InputCompleter do
     end
 
     module Baz
-      remove_const :Con if defined? Con
+      remove_const :CON if defined? CON
       @bar = Bar
       @bazvar = :baz
-      Con = :constant
+      CON = :constant
     end
 
     pry = Pry.new(target: Baz)
@@ -129,7 +145,7 @@ describe Pry::InputCompleter do
 
     b = Pry.binding_for(Bar)
     completer_test(b, pry).call("../@bazvar")
-    completer_test(b, pry).call('/Con')
+    completer_test(b, pry).call('/CON')
   end
 
   it 'should complete for stdlib symbols' do
@@ -158,16 +174,16 @@ describe Pry::InputCompleter do
 
     # Constant
     module Mod
-      remove_const :Con if defined? Con
-      Con = 'Constant'
+      remove_const :CON if defined? CON
+      CON = 'Constant'.freeze
       module Mod2
       end
     end
 
-    completer_test(Mod).call('Con')
+    completer_test(Mod).call('CON')
 
     # Constants or Class Methods
-    completer_test(o).call('Mod::Con')
+    completer_test(o).call('Mod::CON')
 
     # Symbol
     _foo = :symbol
@@ -181,7 +197,8 @@ describe Pry::InputCompleter do
     completer_test(binding).call('o.foo')
 
     # trailing slash
-    expect(Pry::InputCompleter.new(Readline).call('Mod2/', target: Pry.binding_for(Mod)).include?('Mod2/')).to eq(true)
+    expect(Pry::InputCompleter.new(Readline).call('Mod2/', target: Pry.binding_for(Mod))
+      .include?('Mod2/')).to eq(true)
   end
 
   it 'should complete for arbitrary scopes' do
@@ -190,10 +207,10 @@ describe Pry::InputCompleter do
     end
 
     module Baz
-      remove_const :Con if defined? Con
+      remove_const :CON if defined? CON
       @bar = Bar
       @bazvar = :baz
-      Con = :constant
+      CON = :constant
     end
 
     pry = Pry.new(target: Baz)
@@ -201,19 +218,20 @@ describe Pry::InputCompleter do
 
     b = Pry.binding_for(Bar)
     completer_test(b, pry).call("../@bazvar")
-    completer_test(b, pry).call('/Con')
+    completer_test(b, pry).call('/CON')
   end
 
   it 'should not return nil in its output' do
     pry = Pry.new
-    expect(Pry::InputCompleter.new(Readline, pry).call("pry.", target: binding)).not_to include nil
+    expect(Pry::InputCompleter.new(Readline, pry).call("pry.", target: binding))
+      .not_to include nil
   end
 
   it 'completes expressions with all available methods' do
     completer_test(self).call("[].size.chars")
   end
 
-  it 'does not offer methods from blacklisted modules' do
+  it 'does not offer methods from restricted modules' do
     require 'irb'
     completer_test(self, nil, false).call("[].size.parse_printf_format")
   end
@@ -221,14 +239,12 @@ describe Pry::InputCompleter do
   unless Pry::Helpers::Platform.jruby?
     # Classes that override .hash are still hashable in JRuby, for some reason.
     it 'ignores methods from modules that override Object#hash incompatibly' do
-      # skip unless Pry::Helpers::Platform.jruby?
+      require 'irb'
 
       m = Module.new do
-        def self.hash(a, b)
-        end
+        def self.hash; end
 
-        def aaaa
-        end
+        def aaaa; end
       end
 
       completer_test(m, nil, false).call("[].size.aaaa")
