@@ -1,10 +1,38 @@
-require_relative 'helper'
+# frozen_string_literal: true
 
 describe Pry::Hooks do
   before do
     @hooks = Pry::Hooks.new
   end
 
+  describe ".default" do
+    it "returns hooks with default before_session hook" do
+      hooks = described_class.default
+      expect(hooks.hook_exists?('before_session', :default)).to be_truthy
+    end
+
+    context "when pry instance is quiet" do
+      let(:pry_instance) { Pry.new(quiet: true) }
+
+      it "doesn't run the whereami command" do
+        expect(pry_instance).not_to receive(:run_command)
+        hooks = described_class.default
+        hooks.exec_hook(:before_session, StringIO.new, {}, pry_instance)
+      end
+    end
+
+    context "when pry instance is not quiet" do
+      let(:pry_instance) { Pry.new(quiet: false) }
+      let(:output) { StringIO.new }
+
+      it "runs the whereami command" do
+        expect(pry_instance).to receive(:run_command).with('whereami --quiet')
+        hooks = described_class.default
+        hooks.exec_hook(:before_session, StringIO.new, {}, pry_instance)
+      end
+    end
+  end
+
   describe "adding a new hook" do
     it 'should not execute hook while adding it' do
       run = false
@@ -69,7 +97,9 @@ describe Pry::Hooks do
 
         h2.merge!(h1)
         h2.add_hook(:test_hook, :testing2) {}
-        expect(h2.get_hook(:test_hook, :testing2)).not_to eq h1.get_hook(:test_hook, :testing2)
+        expect(h2.get_hook(:test_hook, :testing2)).not_to eq(
+          h1.get_hook(:test_hook, :testing2)
+        )
       end
 
       it 'should NOT overwrite hooks belonging to shared event in receiver' do
@@ -93,14 +123,14 @@ describe Pry::Hooks do
       end
 
       it 'should preserve hook order' do
-        name = ""
+        name = ''
         h1 = Pry::Hooks.new
-        h1.add_hook(:test_hook, :testing3) { name << "h" }
-        h1.add_hook(:test_hook, :testing4) { name << "n" }
+        h1.add_hook(:test_hook, :testing3) { name += "h" }
+        h1.add_hook(:test_hook, :testing4) { name += "n" }
 
         h2 = Pry::Hooks.new
-        h2.add_hook(:test_hook, :testing1) { name << "j" }
-        h2.add_hook(:test_hook, :testing2) { name << "o" }
+        h2.add_hook(:test_hook, :testing1) { name += "j" }
+        h2.add_hook(:test_hook, :testing2) { name += "o" }
 
         h2.merge!(h1)
         h2.exec_hook(:test_hook)
@@ -123,8 +153,12 @@ describe Pry::Hooks do
           h2 = Pry::Hooks.new.add_hook(:test_hook2, :testing) {}
 
           h3 = h2.merge(h1)
-          expect(h3.get_hook(:test_hook, :testing)).to eq h1.get_hook(:test_hook, :testing)
-          expect(h3.get_hook(:test_hook2, :testing)).to eq h2.get_hook(:test_hook2, :testing)
+          expect(h3.get_hook(:test_hook, :testing)).to eq(
+            h1.get_hook(:test_hook, :testing)
+          )
+          expect(h3.get_hook(:test_hook2, :testing)).to eq(
+            h2.get_hook(:test_hook2, :testing)
+          )
         end
 
         it 'should not affect original instances when new hooks are added' do
@@ -148,7 +182,9 @@ describe Pry::Hooks do
       end
 
       hooks_dup = @hooks.dup
-      expect(hooks_dup.get_hook(:test_hook, :testing)).to eq @hooks.get_hook(:test_hook, :testing)
+      expect(hooks_dup.get_hook(:test_hook, :testing)).to eq(
+        @hooks.get_hook(:test_hook, :testing)
+      )
     end
 
     it 'adding a new event to dupped instance should not affect original' do
@@ -157,7 +193,8 @@ describe Pry::Hooks do
 
       hooks_dup.add_hook(:other_test_hook, :testing) { :okay_man }
 
-      expect(hooks_dup.get_hook(:other_test_hook, :testing)).not_to eq @hooks.get_hook(:other_test_hook, :testing)
+      expect(hooks_dup.get_hook(:other_test_hook, :testing))
+        .not_to eq @hooks.get_hook(:other_test_hook, :testing)
     end
 
     it 'adding a new hook to dupped instance should not affect original' do
@@ -166,7 +203,8 @@ describe Pry::Hooks do
 
       hooks_dup.add_hook(:test_hook, :testing2) { :okay_man }
 
-      expect(hooks_dup.get_hook(:test_hook, :testing2)).not_to eq @hooks.get_hook(:test_hook, :testing2)
+      expect(hooks_dup.get_hook(:test_hook, :testing2))
+        .not_to eq @hooks.get_hook(:test_hook, :testing2)
     end
   end
 
@@ -254,7 +292,9 @@ describe Pry::Hooks do
         obj.instance_variable_set(:@test_var, nil)
         class << obj
           attr_accessor :test_var
-          def call() @test_var = true; end
+          def call
+            @test_var = true
+          end
         end
       end
 
@@ -294,7 +334,7 @@ describe Pry::Hooks do
       @hooks.add_hook(:test_hook, :foo2) { raise 'two' }
       @hooks.add_hook(:test_hook, :foo3) { raise 'three' }
       @hooks.exec_hook(:test_hook)
-      expect(@hooks.errors.map(&:message)).to eq ['one', 'two', 'three']
+      expect(@hooks.errors.map(&:message)).to eq %w[one two three]
     end
 
     it 'should return the last exception raised as the return value' do
@@ -309,7 +349,9 @@ describe Pry::Hooks do
     describe "when_started hook" do
       it 'should yield options to the hook' do
         options = nil
-        Pry.config.hooks.add_hook(:when_started, :test_hook) { |target, opt, _| options = opt }
+        Pry.config.hooks.add_hook(:when_started, :test_hook) do |_target, opt, _|
+          options = opt
+        end
 
         redirect_pry_io(StringIO.new("exit"), StringIO.new) do
           Pry.start binding, hello: :baby
@@ -323,7 +365,9 @@ describe Pry::Hooks do
       describe "target" do
         it 'should yield the target, as a binding ' do
           b = nil
-          Pry.config.hooks.add_hook(:when_started, :test_hook) { |target, opt, _| b = target }
+          Pry.config.hooks.add_hook(:when_started, :test_hook) do |target, _opt, _|
+            b = target
+          end
 
           redirect_pry_io(StringIO.new("exit"), StringIO.new) do
             Pry.start 5, hello: :baby
@@ -335,7 +379,9 @@ describe Pry::Hooks do
 
         it 'should yield the target to the hook' do
           b = nil
-          Pry.config.hooks.add_hook(:when_started, :test_hook) { |target, opt, _| b = target }
+          Pry.config.hooks.add_hook(:when_started, :test_hook) do |target, _opt, _|
+            b = target
+          end
 
           redirect_pry_io(StringIO.new("exit"), StringIO.new) do
             Pry.start 5, hello: :baby
@@ -350,9 +396,13 @@ describe Pry::Hooks do
         o = Object.new
         class << o; attr_accessor :value; end
 
-        Pry.config.hooks.add_hook(:when_started, :test_hook) { |target, opt, _pry_| _pry_.binding_stack = [Pry.binding_for(o)] }
+        Pry.config.hooks.add_hook(
+          :when_started, :test_hook
+        ) do |_target, _opt, pry_instance|
+          pry_instance.binding_stack = [Pry.binding_for(o)]
+        end
 
-        redirect_pry_io(InputTester.new("@value = true","exit-all")) do
+        redirect_pry_io(InputTester.new("@value = true", "exit-all")) do
           Pry.start binding, hello: :baby
         end
 
@@ -363,19 +413,22 @@ describe Pry::Hooks do
 
     describe "after_session hook" do
       it 'should always run, even if uncaught exception bubbles out of repl' do
-        o = Pry::Config.new
+        o = OpenStruct.new
         o.great_escape = Class.new(StandardError)
 
-        old_ew = Pry.config.exception_whitelist
-        Pry.config.exception_whitelist << o.great_escape
+        old_ew = Pry.config.unrescued_exceptions
+        Pry.config.unrescued_exceptions << o.great_escape
 
         array = [1, 2, 3, 4, 5]
 
         begin
           redirect_pry_io(StringIO.new("raise great_escape"), StringIO.new) do
-            Pry.start o, hooks: Pry::Hooks.new.add_hook(:after_session, :cleanup) { array = nil }
+            Pry.start(
+              o,
+              hooks: Pry::Hooks.new.add_hook(:after_session, :cleanup) { array = nil }
+            )
           end
-        rescue => ex
+        rescue StandardError => ex
           exception = ex
         end
 
@@ -387,13 +440,15 @@ describe Pry::Hooks do
         expect(array).to eq nil
 
         # cleanup after test
-        Pry.config.exception_whitelist = old_ew
+        Pry.config.unrescued_exceptions = old_ew
       end
 
       describe "before_eval hook" do
         describe "modifying input code" do
           it 'should replace input code with code determined by hook' do
-            hooks = Pry::Hooks.new.add_hook(:before_eval, :quirk) { |code, pry| code.replace(":little_duck") }
+            hooks = Pry::Hooks.new.add_hook(:before_eval, :quirk) do |code, _pry|
+              code.replace(":little_duck")
+            end
             redirect_pry_io(InputTester.new(":jemima", "exit-all"), out = StringIO.new) do
               Pry.start(self, hooks: hooks)
             end
@@ -410,12 +465,21 @@ describe Pry::Hooks do
               end
             end
 
-            hooks = Pry::Hooks.new.add_hook(:before_eval, :quirk) { |code, pry| code.replace(":little_duck") }
+            hooks = Pry::Hooks.new.add_hook(:before_eval, :quirk) do |code, _pry|
+              code.replace(":little_duck")
+            end
 
-            redirect_pry_io(InputTester.new("how-do-you-like-your-blue-eyed-boy-now-mister-death", "exit-all"), out = StringIO.new) do
+            redirect_pry_io(
+              InputTester.new(
+                "how-do-you-like-your-blue-eyed-boy-now-mister-death", "exit-all"
+              ),
+              out = StringIO.new
+            ) do
               Pry.start(self, hooks: hooks, commands: commands)
             end
-            expect(out.string).to match(/in hours of bitterness i imagine balls of sapphire, of metal/)
+            expect(out.string).to match(
+              /in hours of bitterness i imagine balls of sapphire, of metal/
+            )
             expect(out.string).not_to match(/little_duck/)
           end
         end
@@ -436,7 +500,10 @@ describe Pry::Hooks do
         end
 
         it "should print out a notice for each exception raised" do
-          expect(mock_pry("1")).to match(/after_eval hook failed: RuntimeError: Baddums\n.*after_eval hook failed: RuntimeError: Simbads/m)
+          expect(mock_pry("1")).to match(
+            /after_eval\shook\sfailed:\sRuntimeError:\sBaddums\n
+            .*after_eval\shook\sfailed:\sRuntimeError:\sSimbads/xm
+          )
         end
       end
     end
