@@ -1,5 +1,7 @@
-require "helper"
+# frozen_string_literal: true
+
 require "shellwords"
+require 'rbconfig'
 
 RSpec.describe "Hanami integration" do
   before :all do
@@ -8,7 +10,9 @@ RSpec.describe "Hanami integration" do
   end
 
   it "does not enter an infinite loop (#1471, #1621)" do
-    skip "prepend is not supported on this version of Ruby" if RUBY_VERSION.start_with? "1.9"
+    if RUBY_VERSION.start_with? "1.9"
+      skip "prepend is not supported on this version of Ruby"
+    end
     code = <<-RUBY
         require "pry"
         require "timeout"
@@ -32,7 +36,7 @@ RSpec.describe "Hanami integration" do
         Timeout.timeout(1) { Action.new.call("define prison, in the abstract sense") }
         exit 42
     RUBY
-    `#@ruby -I#@pry_dir -e'#{code}'`
-    expect($?.exitstatus).to eq(42)
+    `#{@ruby} -I#{@pry_dir} -e'#{code}'`
+    expect($CHILD_STATUS.exitstatus).to eq(42)
   end
 end
