@@ -1,4 +1,5 @@
-require_relative 'helper'
+# frozen_string_literal: true
+
 require 'set'
 
 describe Pry::Method do
@@ -8,19 +9,22 @@ describe Pry::Method do
   end
 
   describe ".from_str" do
-    it 'should look up instance methods if no methods available and no options provided' do
+    it 'looks up instance methods if no methods available and no options provided' do
       klass = Class.new { def hello; end }
       meth = Pry::Method.from_str(:hello, Pry.binding_for(klass))
       expect(meth).to eq klass.instance_method(:hello)
     end
 
-    it 'should look up methods if no instance methods available and no options provided' do
+    it 'looks up methods if no instance methods available and no options provided' do
       klass = Class.new { def self.hello; end }
       meth = Pry::Method.from_str(:hello, Pry.binding_for(klass))
       expect(meth).to eq klass.method(:hello)
     end
 
-    it 'should look up instance methods first even if methods available and no options provided' do
+    it(
+      'looks up instance methods first even if methods available and no ' \
+      'options provided'
+    ) do
       klass = Class.new do
         def hello; end
 
@@ -36,7 +40,9 @@ describe Pry::Method do
 
         def self.hello; end
       end
-      meth = Pry::Method.from_str(:hello, Pry.binding_for(klass), {"instance-methods" => true})
+      meth = Pry::Method.from_str(
+        :hello, Pry.binding_for(klass), "instance-methods" => true
+      )
       expect(meth).to eq klass.instance_method(:hello)
     end
 
@@ -46,7 +52,7 @@ describe Pry::Method do
 
         def self.hello; end
       end
-      meth = Pry::Method.from_str(:hello, Pry.binding_for(klass), {methods: true})
+      meth = Pry::Method.from_str(:hello, Pry.binding_for(klass), methods: true)
       expect(meth).to eq klass.method(:hello)
     end
 
@@ -70,13 +76,19 @@ describe Pry::Method do
       expect(meth).to eq klass.method(:hello)
     end
 
-    it 'should NOT look up instance methods using the Class#method syntax if no instance methods defined' do
+    it(
+      'should NOT look up instance methods using the Class#method syntax if ' \
+      'no instance methods defined'
+    ) do
       _klass = Class.new { def self.hello; end }
       meth = Pry::Method.from_str("_klass#hello", Pry.binding_for(binding))
       expect(meth).to eq nil
     end
 
-    it 'should NOT look up methods using the object.method syntax if no methods defined' do
+    it(
+      'should NOT look up methods using the object.method syntax if no ' \
+      'methods defined'
+    ) do
       _klass = Class.new { def hello; end }
       meth = Pry::Method.from_str("_klass.hello", Pry.binding_for(binding))
       expect(meth).to eq nil
@@ -113,13 +125,15 @@ describe Pry::Method do
     end
 
     it 'should not raise an exception if receiver does not exist' do
-      expect { Pry::Method.from_str("random_klass.meth", Pry.binding_for(binding)) }.to_not raise_error
+      expect { Pry::Method.from_str("random_klass.meth", Pry.binding_for(binding)) }
+        .to_not raise_error
     end
   end
 
   describe '.from_binding' do
     it 'should be able to pick a method out of a binding' do
-      expect(Pry::Method.from_binding(Class.new { def self.foo; binding; end }.foo).name).to eq "foo"
+      klass = Class.new { def self.foo; binding; end }.foo
+      expect(Pry::Method.from_binding(klass).name).to eq('foo')
     end
 
     it 'should NOT find a method from the toplevel binding' do
@@ -187,7 +201,7 @@ describe Pry::Method do
           @nips = "nips"
           binding
         end
-        alias paella borscht
+        alias_method :paella, :borscht
         def borscht() paella end
       end
 
@@ -230,7 +244,10 @@ describe Pry::Method do
       expect(zuper.owner).to eq m
     end
 
-    it 'should be able to find super methods defined on super-classes when there are modules in the way' do
+    it(
+      'should be able to find super methods defined on super-classes when ' \
+      'there are modules in the way'
+    ) do
       a = Class.new { def rar; 4; end }
       m = Module.new { def mooo; 4; end }
       b = Class.new(a) { def rar; super; end; include m }
@@ -239,7 +256,7 @@ describe Pry::Method do
       expect(zuper.owner).to eq a
     end
 
-    it 'should be able to jump up multiple levels of bound method, even through modules' do
+    it 'jumps up multiple levels of bound method, even through modules' do
       a = Class.new { def rar; 4; end }
       m = Module.new { def rar; 4; end }
       b = Class.new(a) { def rar; super; end; include m }
@@ -260,8 +277,16 @@ describe Pry::Method do
       should_find_method('meth')
     end
 
-    it 'should be able to find private and protected instance methods defined in a class' do
-      @class = Class.new { protected; def prot; 1; end; private; def priv; 1; end }
+    it 'finds private and protected instance methods defined in a class' do
+      @class = Class.new do
+        protected
+
+        def prot; 1; end
+
+        private
+
+        def priv; 1; end
+      end
       should_find_method('priv')
       should_find_method('prot')
     end
@@ -276,14 +301,14 @@ describe Pry::Method do
       should_find_method('meth')
     end
 
-    it 'should be able to find instance methods defined in modules included into this class' do
+    it 'finds instance methods defined in modules included into this class' do
       @class = Class.new do
         include(Module.new { def meth; 1; end })
       end
       should_find_method('meth')
     end
 
-    it 'should be able to find instance methods defined in modules included into super-classes' do
+    it 'finds instance methods defined in modules included into super-classes' do
       super_class = Class.new do
         include(Module.new { def meth; 1; end })
       end
@@ -296,7 +321,8 @@ describe Pry::Method do
         include(Module.new { def meth; 1; end })
       end
       @class = Class.new(super_class) { def meth; 2; end }
-      expect(Pry::Method.all_from_class(@class).detect { |x| x.name == 'meth' }.owner).to eq @class
+      expect(Pry::Method.all_from_class(@class).detect { |x| x.name == 'meth' }.owner)
+        .to eq @class
     end
 
     it 'should be able to find methods defined on a singleton class' do
@@ -322,9 +348,9 @@ describe Pry::Method do
       end
 
       it "should find methods defined in modules included into the object's class" do
-        @obj = Class.new {
+        @obj = Class.new do
           include(Module.new { def meth; 1; end })
-        }.new
+        end.new
         should_find_method('meth')
       end
 
@@ -351,11 +377,11 @@ describe Pry::Method do
       end
 
       it "should work in the face of an overridden send" do
-        @obj = Class.new {
+        @obj = Class.new do
           def meth; 1; end
 
           def send; raise EOFError; end
-        }.new
+        end.new
         should_find_method('meth')
       end
     end
@@ -398,8 +424,11 @@ describe Pry::Method do
       end
 
       it "should attribute overridden methods to the sub-class' singleton class" do
-        @class = Class.new(Class.new { class << self; def meth; 1; end; end }) { class << self; def meth; 1; end; end }
-        expect(Pry::Method.all_from_obj(@class).detect { |x| x.name == 'meth' }.owner).to eq(class << @class; self; end)
+        @class = Class.new(Class.new { class << self; def meth; 1; end; end }) do
+          class << self; def meth; 1; end; end
+        end
+        expect(Pry::Method.all_from_obj(@class).detect { |x| x.name == 'meth' }.owner)
+          .to eq(class << @class; self; end)
       end
 
       it "should attrbute overridden methods to the class not the module" do
@@ -409,12 +438,17 @@ describe Pry::Method do
           end
           extend(Module.new { def meth; 1; end })
         end
-        expect(Pry::Method.all_from_obj(@class).detect { |x| x.name == 'meth' }.owner).to eq(class << @class; self; end)
+        expect(Pry::Method.all_from_obj(@class).detect { |x| x.name == 'meth' }.owner)
+          .to eq(class << @class; self; end)
       end
 
-      it "should attribute overridden methods to the relevant singleton class in preference to Class" do
+      it(
+        "attributes overridden methods to the relevant singleton class in " \
+        "preference to Class"
+      ) do
         @class = Class.new { class << self; def allocate; 1; end; end }
-        expect(Pry::Method.all_from_obj(@class).detect { |x| x.name == 'allocate' }.owner).to eq(class << @class; self; end)
+        expect(Pry::Method.all_from_obj(@class).detect { |x| x.name == 'allocate' }.owner)
+          .to eq(class << @class; self; end)
       end
     end
 
@@ -437,15 +471,20 @@ describe Pry::Method do
       def eigen_class(obj); class << obj; self; end; end
 
       it "should look at a class and then its superclass" do
-        expect(Pry::Method.instance_resolution_order(LS::Next)).to eq [LS::Next] + Pry::Method.instance_resolution_order(LS::Top)
+        expect(Pry::Method.instance_resolution_order(LS::Next))
+          .to eq [LS::Next] + Pry::Method.instance_resolution_order(LS::Top)
       end
 
       it "should include the included modules between a class and its superclass" do
-        expect(Pry::Method.instance_resolution_order(LS::Low)).to eq [LS::Low, LS::P, LS::N, LS::M] + Pry::Method.instance_resolution_order(LS::Next)
+        expect(Pry::Method.instance_resolution_order(LS::Low)).to eq(
+          [LS::Low, LS::P, LS::N, LS::M] + Pry::Method.instance_resolution_order(LS::Next)
+        )
       end
 
       it "should not include modules extended into the class" do
-        expect(Pry::Method.instance_resolution_order(LS::Bottom)).to eq [LS::Bottom] + Pry::Method.instance_resolution_order(LS::Lower)
+        expect(Pry::Method.instance_resolution_order(LS::Bottom)).to eq(
+          [LS::Bottom] + Pry::Method.instance_resolution_order(LS::Lower)
+        )
       end
 
       it "should include included modules for Modules" do
@@ -454,20 +493,28 @@ describe Pry::Method do
 
       it "should include the singleton class of objects" do
         obj = LS::Low.new
-        expect(Pry::Method.resolution_order(obj)).to eq [eigen_class(obj)] + Pry::Method.instance_resolution_order(LS::Low)
+        expect(Pry::Method.resolution_order(obj)).to eq(
+          [eigen_class(obj)] + Pry::Method.instance_resolution_order(LS::Low)
+        )
       end
 
       it "should not include singleton classes of numbers" do
         target_class = 4.class
-        expect(Pry::Method.resolution_order(4)).to eq Pry::Method.instance_resolution_order(target_class)
+        expect(Pry::Method.resolution_order(4)).to eq(
+          Pry::Method.instance_resolution_order(target_class)
+        )
       end
 
       it "should include singleton classes for classes" do
-        expect(Pry::Method.resolution_order(LS::Low)).to eq [eigen_class(LS::Low)] + Pry::Method.resolution_order(LS::Next)
+        expect(Pry::Method.resolution_order(LS::Low)).to eq(
+          [eigen_class(LS::Low)] + Pry::Method.resolution_order(LS::Next)
+        )
       end
 
       it "should include modules included into singleton classes" do
-        expect(Pry::Method.resolution_order(LS::Lower)).to eq [eigen_class(LS::Lower), LS::N, LS::M] + Pry::Method.resolution_order(LS::Low)
+        expect(Pry::Method.resolution_order(LS::Lower)).to eq(
+          [eigen_class(LS::Lower), LS::N, LS::M] + Pry::Method.resolution_order(LS::Low)
+        )
       end
 
       it "should include modules at most once" do
@@ -475,14 +522,20 @@ describe Pry::Method do
       end
 
       it "should include modules at the point which they would be reached" do
-        expect(Pry::Method.resolution_order(LS::Bottom)).to eq [eigen_class(LS::Bottom), LS::O] + (Pry::Method.resolution_order(LS::Lower))
+        expect(Pry::Method.resolution_order(LS::Bottom)).to eq(
+          [eigen_class(LS::Bottom), LS::O] + Pry::Method.resolution_order(LS::Lower)
+        )
       end
 
-      it "should include the Pry::Method.instance_resolution_order of Class after the singleton classes" do
-        expect(Pry::Method.resolution_order(LS::Top)).to eq(
-                                                           [eigen_class(LS::Top), eigen_class(Object), eigen_class(BasicObject),
-                                                            *Pry::Method.instance_resolution_order(Class)]
-                                                         )
+      it(
+        "includes the Pry::Method.instance_resolution_order of Class after " \
+        "the singleton classes"
+      ) do
+        singleton_classes = [
+          eigen_class(LS::Top), eigen_class(Object), eigen_class(BasicObject),
+          *Pry::Method.instance_resolution_order(Class)
+        ]
+        expect(Pry::Method.resolution_order(LS::Top)).to eq(singleton_classes)
       end
     end
   end
@@ -499,23 +552,21 @@ describe Pry::Method do
 
   describe 'method aliases' do
     before do
-      @class = Class.new {
-        def eat
-        end
+      @class = Class.new do
+        def eat; end
 
-        alias fress eat
+        alias_method :fress, :eat
         alias_method :omnomnom, :fress
 
-        def eruct
-        end
-      }
+        def eruct; end
+      end
     end
 
     it 'should be able to find method aliases' do
       meth = Pry::Method(@class.new.method(:eat))
       aliases = Set.new(meth.aliases)
 
-      expect(aliases).to eq Set.new(["fress", "omnomnom"])
+      expect(aliases).to eq Set.new(%w[fress omnomnom])
     end
 
     it 'should return an empty Array if cannot find aliases' do
@@ -532,7 +583,8 @@ describe Pry::Method do
       # top-level methods get added as private instance methods on Object
       class Object
         private
-        def my_top_level_method ; end
+
+        def my_top_level_method; end
         alias my_other_top_level_method my_top_level_method
       end
 
@@ -545,7 +597,7 @@ describe Pry::Method do
     end
 
     it 'should be able to find aliases for methods implemented in C' do
-      meth = Pry::Method(Hash.new.method(:key?))
+      meth = Pry::Method({}.method(:key?))
       aliases = Set.new(meth.aliases)
 
       expect(aliases).to eq Set.new(["include?", "member?", "has_key?"])
@@ -554,7 +606,7 @@ describe Pry::Method do
 
   describe '.signature' do
     before do
-      @class = Class.new {
+      @class = Class.new do
         def self.standard_arg(arg) end
 
         def self.block_arg(&block) end
@@ -562,7 +614,7 @@ describe Pry::Method do
         def self.rest(*splat) end
 
         def self.optional(option = nil) end
-      }
+      end
     end
 
     it 'should print the name of regular args' do
@@ -588,16 +640,85 @@ describe Pry::Method do
     # keyword args are only on >= Ruby 2.1
     if Gem::Version.new(RUBY_VERSION) >= Gem::Version.new("2.1")
       it 'should print the name of keyword args, with :? after the arg name' do
-        eval %{def @class.keyword(keyword_arg: "") end}
+        eval <<-RUBY, binding, __FILE__, __LINE__ + 1
+          def @class.keyword(keyword_arg: '')
+          end
+        RUBY
         signature = Pry::Method.new(@class.method(:keyword)).signature
         expect(signature).to eq("keyword(keyword_arg:?)")
       end
 
       it 'should print the name of keyword args, with : after the arg name' do
-        eval %{def @class.required_keyword(required_key:) end}
+        eval <<-RUBY, binding, __FILE__, __LINE__ + 1
+          def @class.required_keyword(required_key:)
+          end
+        RUBY
         signature = Pry::Method.new(@class.method(:required_keyword)).signature
         expect(signature).to eq("required_keyword(required_key:)")
       end
     end
   end
+
+  describe "#owner" do
+    context "when it is overriden in Object" do
+      before do
+        module OwnerMod
+          def owner
+            :fail
+          end
+        end
+
+        Object.__send__(:include, OwnerMod)
+      end
+
+      after { Object.remove_const(:OwnerMod) }
+
+      it "correctly reports the owner" do
+        method = described_class.new(method(:puts))
+        expect(method.owner).not_to eq(:fail)
+      end
+    end
+  end
+
+  describe "#parameters" do
+    context "when it is overriden in Object" do
+      before do
+        module ParametersMod
+          def parameters
+            :fail
+          end
+        end
+
+        Object.__send__(:include, ParametersMod)
+      end
+
+      after { Object.remove_const(:ParametersMod) }
+
+      it "correctly reports the parameters" do
+        method = described_class.new(method(:puts))
+        expect(method.parameters).not_to eq(:fail)
+      end
+    end
+  end
+
+  describe "#receiver" do
+    context "when it is overriden in Object" do
+      before do
+        module ReceiverMod
+          def receiver
+            :fail
+          end
+        end
+
+        Object.__send__(:include, ReceiverMod)
+      end
+
+      after { Object.remove_const(:ReceiverMod) }
+
+      it "correctly reports the receiver" do
+        method = described_class.new(method(:puts))
+        expect(method.receiver).not_to eq(:fail)
+      end
+    end
+  end
 end
