@@ -1,19 +1,21 @@
-require_relative 'helper'
+# frozen_string_literal: true
 
 describe "Sticky locals (_file_ and friends)" do
   it 'locals should all exist upon initialization' do
-    expect { pry_eval '_file_', '_dir_', '_ex_', '_pry_', '_' }.to_not raise_error
+    expect { pry_eval '_file_', '_dir_', '_ex_', 'pry_instance', '_' }
+      .to_not raise_error
   end
 
   it 'locals should still exist after cd-ing into a new context' do
-    expect { pry_eval 'cd 0', '_file_', '_dir_', '_ex_', '_pry_', '_' }.to_not raise_error
+    expect { pry_eval('cd 0', '_file_', '_dir_', '_ex_', 'pry_instance', '_') }
+      .to_not raise_error
   end
 
-  it 'locals should keep value after cd-ing (_pry_)' do
+  it 'locals should keep value after cd-ing (pry_instance)' do
     pry_tester.tap do |t|
-      pry = t.eval '_pry_'
+      pry = t.eval 'pry_instance'
       t.eval 'cd 0'
-      expect(t.eval('_pry_')).to eq(pry)
+      expect(t.eval('pry_instance')).to eq(pry)
     end
   end
 
@@ -47,11 +49,11 @@ describe "Sticky locals (_file_ and friends)" do
       set_file_and_dir_locals("/blah/ostrich.rb")
     end
 
-    expect(pry_eval('file-and-dir-test', 'cd 0', '_file_')).
-      to match(/\/blah\/ostrich\.rb/)
+    expect(pry_eval('file-and-dir-test', 'cd 0', '_file_'))
+      .to match(%r{/blah/ostrich\.rb})
 
-    expect(pry_eval('file-and-dir-test', 'cd 0', '_dir_')).
-      to match(/\/blah/)
+    expect(pry_eval('file-and-dir-test', 'cd 0', '_dir_'))
+      .to match(%r{/blah})
 
     Pry.config.commands.delete "file-and-dir-test"
   end
@@ -103,7 +105,7 @@ describe "Sticky locals (_file_ and friends)" do
         o = Object.new
         redirect_pry_io(InputTester.new("@value = test_local",
                                         "exit-all")) do
-          Pry.start(o, extra_sticky_locals: { test_local: :john } )
+          Pry.start(o, extra_sticky_locals: { test_local: :john })
         end
 
         expect(o.instance_variable_get(:@value)).to eq :john
@@ -111,11 +113,20 @@ describe "Sticky locals (_file_ and friends)" do
 
       it 'should define multiple sticky locals' do
         o = Object.new
-        redirect_pry_io(InputTester.new("@value1 = test_local1",
-                                        "@value2 = test_local2",
-                                        "exit-all")) do
-          Pry.start(o, extra_sticky_locals: { test_local1: :john ,
-                      test_local2: :carl} )
+        redirect_pry_io(
+          InputTester.new(
+            "@value1 = test_local1",
+            "@value2 = test_local2",
+            "exit-all"
+          )
+        ) do
+          Pry.start(
+            o,
+            extra_sticky_locals: {
+              test_local1: :john,
+              test_local2: :carl
+            }
+          )
         end
 
         expect(o.instance_variable_get(:@value1)).to eq :john
@@ -126,7 +137,7 @@ describe "Sticky locals (_file_ and friends)" do
         o = Object.new
         redirect_pry_io(InputTester.new("@value = test_local",
                                         "exit-all")) do
-          Pry.start(o, extra_sticky_locals: { test_local: proc { :john }} )
+          Pry.start(o, extra_sticky_locals: { test_local: proc { :john } })
         end
 
         expect(o.instance_variable_get(:@value)).to eq :john
@@ -150,13 +161,13 @@ describe "Sticky locals (_file_ and friends)" do
 
     it 'should create a new sticky local' do
       t = pry_tester
-      t.eval "_pry_.add_sticky_local(:test_local){ :test_value }"
+      t.eval "pry_instance.add_sticky_local(:test_local){ :test_value }"
       expect(t.eval("test_local")).to eq(:test_value)
     end
 
     it 'should still exist after cd-ing into new binding' do
       t = pry_tester
-      t.eval "_pry_.add_sticky_local(:test_local){ :test_value }"
+      t.eval "pry_instance.add_sticky_local(:test_local){ :test_value }"
       t.eval "cd Object.new"
       expect(t.eval("test_local")).to eq(:test_value)
     end
