@@ -1,4 +1,4 @@
-require_relative 'helper'
+# frozen_string_literal: true
 
 describe Pry::WrappedModule do
   describe "#initialize" do
@@ -9,15 +9,14 @@ describe Pry::WrappedModule do
 
   describe "candidates" do
     class Host
-      %w(spec/fixtures/candidate_helper1.rb
-         spec/fixtures/candidate_helper2.rb).each do |file|
-        binding.eval File.read(file), file, 1
+      %w[spec/fixtures/candidate_helper1.rb
+         spec/fixtures/candidate_helper2.rb].each do |file|
+        binding.eval(File.read(file), file, 1) # rubocop:disable Security/Eval
       end
 
       # rank 2
       class CandidateTest
-        def test6
-        end
+        def test6; end
       end
 
       class PitifullyBlank
@@ -29,8 +28,7 @@ describe Pry::WrappedModule do
         class DoublyNested
           # nested docs
           class TriplyNested
-            def nested_method
-            end
+            def nested_method; end
           end
         end
       end
@@ -52,19 +50,25 @@ describe Pry::WrappedModule do
 
     describe "ordering of candidates" do
       it 'should return class with largest number of methods as primary candidate' do
-        expect(Pry::WrappedModule(Host::CandidateTest).candidate(0).file).to match(/helper1/)
+        expect(Pry::WrappedModule(Host::CandidateTest).candidate(0).file)
+          .to match(/helper1/)
       end
 
-      it 'should return class with second largest number of methods as second ranked candidate' do
-        expect(Pry::WrappedModule(Host::CandidateTest).candidate(1).file).to match(/helper2/)
+      it(
+        'returns class with second largest number of methods as second ranked candidate'
+      ) do
+        expect(Pry::WrappedModule(Host::CandidateTest).candidate(1).file)
+          .to match(/helper2/)
       end
 
-      it 'should return class with third largest number of methods as third ranked candidate' do
-        expect(Pry::WrappedModule(Host::CandidateTest).candidate(2).file).to match(/#{__FILE__}/)
+      it 'returns class with third largest number of methods as third ranked candidate' do
+        expect(Pry::WrappedModule(Host::CandidateTest).candidate(2).file)
+          .to match(/#{__FILE__}/)
       end
 
       it 'should raise when trying to access non-existent candidate' do
-        expect { Pry::WrappedModule(Host::CandidateTest).candidate(3) }.to raise_error Pry::CommandError
+        expect { Pry::WrappedModule(Host::CandidateTest).candidate(3) }
+          .to raise_error Pry::CommandError
       end
     end
 
@@ -74,9 +78,10 @@ describe Pry::WrappedModule do
         expect(wm.source_location).to eq wm.candidate(0).source_location
       end
 
-      it 'should return the location of the outer module if an inner module has methods' do
+      it 'returns the location of the outer module if an inner module has methods' do
         wm = Pry::WrappedModule(Host::ForeverAlone)
-        expect(File.expand_path(wm.source_location.first)).to eq File.expand_path(__FILE__)
+        expect(File.expand_path(wm.source_location.first))
+          .to eq File.expand_path(__FILE__)
         expect(wm.source_location.last).to eq Host::FOREVER_ALONE_LINE
       end
 
@@ -92,20 +97,25 @@ describe Pry::WrappedModule do
       end
 
       it 'should return source for highest ranked candidate' do
-        expect(Pry::WrappedModule(Host::CandidateTest).candidate(0).source).to match(/test1/)
+        expect(Pry::WrappedModule(Host::CandidateTest).candidate(0).source)
+          .to match(/test1/)
       end
 
       it 'should return source for second ranked candidate' do
-        expect(Pry::WrappedModule(Host::CandidateTest).candidate(1).source).to match(/test4/)
+        expect(Pry::WrappedModule(Host::CandidateTest).candidate(1).source)
+          .to match(/test4/)
       end
 
       it 'should return source for third ranked candidate' do
-        expect(Pry::WrappedModule(Host::CandidateTest).candidate(2).source).to match(/test6/)
+        expect(Pry::WrappedModule(Host::CandidateTest).candidate(2).source)
+          .to match(/test6/)
       end
 
       it 'should return source for deeply nested class' do
-        expect(Pry::WrappedModule(Host::ForeverAlone::DoublyNested::TriplyNested).source).to match(/nested_method/)
-        expect(Pry::WrappedModule(Host::ForeverAlone::DoublyNested::TriplyNested).source.lines.count).to eq 4
+        expect(Pry::WrappedModule(Host::ForeverAlone::DoublyNested::TriplyNested).source)
+          .to match(/nested_method/)
+        mod = Pry::WrappedModule(Host::ForeverAlone::DoublyNested::TriplyNested)
+        expect(mod.source.lines.count).to eq(3)
       end
     end
 
@@ -116,19 +126,23 @@ describe Pry::WrappedModule do
       end
 
       it 'should return doc for highest ranked candidate' do
-        expect(Pry::WrappedModule(Host::CandidateTest).candidate(0).doc).to match(/rank 0/)
+        expect(Pry::WrappedModule(Host::CandidateTest).candidate(0).doc)
+          .to match(/rank 0/)
       end
 
       it 'should return doc for second ranked candidate' do
-        expect(Pry::WrappedModule(Host::CandidateTest).candidate(1).doc).to match(/rank 1/)
+        expect(Pry::WrappedModule(Host::CandidateTest).candidate(1).doc)
+          .to match(/rank 1/)
       end
 
       it 'should return doc for third ranked candidate' do
-        expect(Pry::WrappedModule(Host::CandidateTest).candidate(2).doc).to match(/rank 2/)
+        expect(Pry::WrappedModule(Host::CandidateTest).candidate(2).doc)
+          .to match(/rank 2/)
       end
 
       it 'should return docs for deeply nested class' do
-        expect(Pry::WrappedModule(Host::ForeverAlone::DoublyNested::TriplyNested).doc).to match(/nested docs/)
+        expect(Pry::WrappedModule(Host::ForeverAlone::DoublyNested::TriplyNested).doc)
+          .to match(/nested docs/)
       end
     end
   end
@@ -164,13 +178,15 @@ describe Pry::WrappedModule do
     end
 
     example "of singleton classes of anonymous classes should not be empty" do
-      expect(Pry::WrappedModule.new(class << Class.new; self; end).method_prefix).to match(/#<Class:.*>./)
+      expect(Pry::WrappedModule.new(class << Class.new; self; end).method_prefix)
+        .to match(/#<Class:.*>./)
     end
   end
 
   describe ".singleton_class?" do
     it "should be true for singleton classes" do
-      expect(Pry::WrappedModule.new(class << ""; self; end).singleton_class?).to eq true
+      mod = Pry::WrappedModule.new(class << Object.new; self; end)
+      expect(mod).to be_singleton_class
     end
 
     it "should be false for normal classes" do
@@ -184,12 +200,17 @@ describe Pry::WrappedModule do
 
   describe ".singleton_instance" do
     it "should raise an exception when called on a non-singleton-class" do
-      expect { Pry::WrappedModule.new(Class).singleton_instance }.to raise_error ArgumentError
+      expect { Pry::WrappedModule.new(Class).singleton_instance }
+        .to raise_error ArgumentError
     end
 
     it "should return the attached object" do
-      expect(Pry::WrappedModule.new(class << "hi"; self; end).singleton_instance).to eq "hi"
-      expect(Pry::WrappedModule.new(class << Object; self; end).singleton_instance).to equal(Object)
+      instance = Object.new
+      mod = class << instance; self; end
+      expect(Pry::WrappedModule.new(mod).singleton_instance).to eq(instance)
+
+      klass = class << Object; self; end
+      expect(Pry::WrappedModule.new(klass).singleton_instance).to equal(Object)
     end
   end
 
